                                                                  // Persistence of Vision Ray Tracer Scene Description File
// File: ?.pov
// Vers: 3.6
// Desc: Basic Scene Example
// Date: mm/dd/yy
// Auth: ?
// +RFtime.rad +RFI

#version 3.7;

#include "colors.inc"
#include "shapes.inc"    

// Radiosity +RFtime.rad +RFO or +RFI (O Output/save I input/load)
                                   // was 5
#declare useRad                 = 0; // 1=load 2=save
#declare radQuality             = 4; // 1-10 1=low 10=high     // norad tood 36 minutes  with rad 2h33m
#declare useArea                = 1; 
#declare useLight               = 1;  
#declare useHDR                 = 1;
#declare useFocalBlur           = 1; // 1-10  used 6 
#declare useTestTex             = 0;
#declare useSubSurface          = 0; // 1-10 used 4
#declare showStar               = 1;        
#declare showWater              = 1;
#declare isoAccuracy            = 0.0005;  // 0.0005 3m27s    
#declare showSand               = 1;  
#declare showRocks              = 1;
#declare showStone              = 1;     
#declare hfRes                  = 1500;  
#declare usePhotons             = 0;
#declare showSeaweed            = 1;
#declare showAnemone            = 1;  
#declare showLimpets            = 1;
#declare showBarnacles          = 1; 
#declare showStones             = 1;

global_settings{ assumed_gamma 1.0 }                                                                                                                                 


 
// radiosity (global illumination) settings
global_settings {   
#if(usePhotons)
  photons {
    spacing 0.03
    media 100
    autostop 0
    jitter 0
  }
#end          


#if(useSubSurface)
  mm_per_unit 100
  subsurface { samples 10*useSubSurface, 2*useSubSurface radiosity on}// do another render with this on..
#end

#if(useRad)
ambient_light 0
  radiosity {

#if(useRad = 2)
    pretrace_start 0.08           // start pretrace at this size
    pretrace_end   0.001           // end pretrace at this size
#end
#if(useRad = 1)
    pretrace_start 1           // start pretrace at this size
    pretrace_end   1           // end pretrace at this size
    always_sample off  // 
#end

    count 20*radQuality 50*radQuality                      // higher -> higher quality (1..1600) [35]

    nearest_count 10+(radQuality) 5 //10+(radQuality/2)               // higher -> higher quality (1..10) [5]

    low_error_factor .5           // reduce error_bound during last pretrace step
    gray_threshold 0.0            // increase for weakening colors (0..1) [0]
    minimum_reuse 0.015           // reuse of old radiosity samples [0.015]
//    maximum_reuse 0.1
    adc_bailout 0.01/2
    error_bound 1.5-(radQuality/10)               // higher -> smoother, less accurate [1.8]
    recursion_limit 3             // how much interreflections are calculated (1..5+) [3]
    brightness 0.5                  // brightness of radiosity effects (0..1) [1]
    normal on                  // take surface normals into account [off]

//  media on                    // take media into account [off]
    //save_file "file_name"       // save radiosity data
    //load_file "file_name"       // load saved radiosity data
    //always_sample off           // turn sampling in final trace off [on]
    //max_sample 1.0              // maximum brightness of samples
  }
#end 
}

 // Create an infinite sphere around scene and allow any pigment on it
sky_sphere {
  pigment {
    gradient y triangle_wave colour_map { [ 0.0 rgb <0.6, 0.5, 1> ] [ 1.0 color rgb <0.3,0.7, 1> ] } translate <0, 1, 0> 
  }
}


camera {        // was 13
  location  <2, 4, -6.0>      
//  location  <1.5, 1.3, -3.0> // stones on left     
//  location  <2, 34, 4> // high up     
//  location  <2.5, -0.45,0>  // close up on big rock near back
//  location  <7.5, 2.25,-2.5>  // close up on starfish stone
  direction 1.5*z
  right     x*image_width/image_height
  look_at <2, 0.4, 1> //<3.075, 1, -2.25>  
//  look_at <0, 0, 1> // stones on left
//  look_at <2, 0.4, 6> // high up
//  look_at <2.5, -0.45, 5> // close up on big rock near back
//  look_at <5.75-1.8, -0.225, 2.15> // close up on starfish stone
  
#if(useFocalBlur)
  aperture 0.0005          // [0...N] larger is narrower depth of field (blurrier)
  blur_samples useFocalBlur*10       // number of rays per pixel for sampling
  focal_point <2.8, 0.2, 2> //<3.075, 1, -2.25>
  confidence 0.9+(0.009*useFocalBlur) //0.8999+(useFocalBlur/1000)           // [0...<1] when to move on while sampling (smaller is less accurate)
  variance 1/(20000*useFocalBlur)            // [0...1] how precise to calculate (smaller is more accurate)
#end
}

/*
cylinder { <-2, 0, -10> <-2, 0, 10> 0.025 pigment { rgb <1, 0, 0> } }
cylinder { <-1, 0, -10> <-1, 0, 10> 0.025 pigment { rgb <0, 1, 0> } }
cylinder { <0 0, -10> <0, 0, 10> 0.025 pigment { rgb <0, 0, 1> } }
cylinder { <1 0, -10> <1, 0, 10> 0.025 pigment { rgb <1, 1, 0> } }
cylinder { <2, 0, -10> <2, 0, 10> 0.025 pigment { rgb <1, 0, 1> } }
cylinder { <3, 0, -10> <3, 0, 10> 0.025 pigment { rgb <0, 1, 1> } }
cylinder { <4, 0, -10> <4, 0, 10> 0.025 pigment { rgb <1, 1, 1> } }

cylinder { <-10, 0, -2> <10, 0, -2> 0.025 pigment { rgb <1, 0, 0> } }
cylinder { <-10, 0, -1> <10, 0, -1> 0.025 pigment { rgb <0, 1, 0> } }
cylinder { <-10, 0, 0> <10, 0, 0> 0.025 pigment { rgb <0, 0, 1> } }
cylinder { <-10, 0, 1> <10, 0, 1> 0.025 pigment { rgb <1, 1, 0> } }
cylinder { <-10, 0, 2> <10, 0, 2> 0.025 pigment { rgb <1, 0, 1> } }
cylinder { <-10, 0, 3> <10, 0, 3> 0.025 pigment { rgb <0, 1, 1> } }
*/

#declare generalRand = seed(2150);   
#declare lgeneralRand = seed(15231);   
#declare sgeneralRand = seed(126);   
#declare stngeneralRand = seed(25);   
#declare tgeneralRand = seed(56);   
#declare ageneralRand = seed(1556);   
#declare bgeneralRand = seed(3456);   
#declare mossRand = seed(1245);   

// Macros to return a random number

#macro gr(num)
        rand(generalRand)*num
#end

// seaweed rand
#macro sr(num)
        rand(sgeneralRand)*num
#end

//stone rand

#macro stnr(num)
        rand(stngeneralRand)*num
#end

#macro tr(num)
        rand(tgeneralRand)*num
#end

#macro ar(num)
        rand(ageneralRand)*num
#end

#macro lr(num)
        rand(lgeneralRand)*num
#end

#macro br(num)
        rand(bgeneralRand)*num
#end

#macro mr(num)
        rand(mossRand)*num
#end



// use trace to place an object onto a surface
#macro Place_Object(Surface, Object, Pos, Norm)
    //Allow the user to pass scalars as vectors
    #local Pos = Pos + <0,0,0>;

    //Trace onto the surface
    #local N = <0,0,0>;
    #local SO = trace(Surface, Pos, z, N);

    //Check if we hit the surface
    #if (vlength(N)>0)   
    #warning "Hit"
        //place the object
        object {
            Object
  
            //Adjust the Normal if the user wants us to
            #if (Norm)
                Reorient_Trans(z,N)
            #end

            //Translate to final position
            translate SO
        }
    #else
        #warning "Missed"
    #end
#end // End Macro

#macro Drop_Object(Surface, Object, Pos, Norm)
    //Allow the user to pass scalars as vectors
    #local Pos = Pos + <0,0,0>;

    //Trace onto the surface
    #local N = <0,0,0>;
    #local SO = trace(Surface, Pos, -y, N);

    //Check if we hit the surface
    #if (vlength(N)>0)   
    #warning "Hit"
        //place the object
        object {
            Object
  
            //Adjust the Normal if the user wants us to
            #if (Norm)
                Reorient_Trans(y,N)
            #end

            //Translate to final position
            translate SO
        }
    #else
        #warning "Missed"
    #end
#end // End Macro

#declare f_distribution = function
{
  pow(f_boxed(x,y,z)*f_granite(x*5, y*5, z*5),2)
}


#if(useLight) 
light_source {
  0*x                 // light's position (translated below)
  color rgb <1.5, 1.1, 0.8>*0.25    // light's color   // was .25
#if(useArea)
  area_light
  <20, 0, 0> <0, 0, 20> // lights spread out across this distance (x * z)
  8, 8                // total number of lights in grid (4x*4z = 16 lights)
  adaptive 0          // 0,1,2,3...
  jitter              // adds random softening of light
  circular            // make the shape of the light circular
  orient              // orient light
#end
  translate <-70, 30, -30>*20   // <x y z> position of light  
//  translate <10, 40, 0>   // <x y z> position of light  
  // light_source { ...
  // put this inside a light_source to add light fading
  fade_distance 40000
  fade_power 2
#if(usePhotons)
    photons { reflection on refraction on }
#end
}
#end  

#if(useTestTex)
#declare starTex = material {
texture {
        
            pigment { 
            rgb <0.7, 0.1, 0.00>  
            }
finish { diffuse albedo 0.5 specular albedo 0.05 roughness 0.05 brilliance 1.4 reflection { 0.001, 0.005 fresnel on } conserve_energy 
#if(useSubSurface)
      subsurface { translucency <1.09 1.59 1.79> }  //0.9
#end

 }
 normal { crackle 3 scale 0.0115 turbulence 0.015 omega 0.7 lambda 5   } 
}
    interior { ior 1.45 }
}
#else
#declare starTex = material {
texture {
        
            pigment { crackle scale 0.0115 turbulence 0.015 omega 0.7 lambda 5  
            colour_map { 
            [ 0.0 rgb <0.7, 0.1, 0.001>*0.4 ] 
            [ 0.05 rgb <0.7, 0.1, 0.001>*0.6 ] 
            [ 0.2 rgb <0.7, 0.1, 0.001> ] 
            [ 1.0 rgb <0.45, 0.005, 0.001> ] 
/*
            [ 0.0 rgbt <0.06, 0.05, 0.001, 0.1> ] 
            [ 0.05 rgbt <0.07, 0.01, 0.0005, 0.1> ] 
            [ 0.2 rgbt <0.7, 0.1, 0.00, 0.1> ] 
            [ 1.0 rgbt <0.45, 0.005, 0.001, 0.1> ] 
*/
            } }
finish { diffuse albedo 0.5 specular albedo 0.05 roughness 0.05 brilliance 1.4 reflection { 0.001, 0.005 fresnel on } conserve_energy ior 1.45
#if(useSubSurface)
      subsurface { translucency <1.09 1.59 1.79>*2 }  //0.9
#end

 }
 normal { crackle 5 scale 0.0115 turbulence 0.015 omega 0.7 lambda 5   } 
} 
texture {
        
            pigment { wrinkles triangle_wave scale 0.025 turbulence 0.35 omega 0.8 lambda 3.2  
            colour_map { 
            [ 0.0 rgbt <0.7, 0.6, 0.001, 0.25> ] 
            [ 0.4 rgbt <0.7, 0.3, 0.001, 1> ] 
            [ 0.7 rgbt <0.7, 0.3, 0.001, 0.5> ] 
            [ 1.0 rgbt <0.5, 0.05, 0.001, 1> ] 
           } }
}
    interior { ior 1.45 }
}
#end

#declare starTexSpot = texture {
    pigment { rgb 1 }
finish { diffuse albedo 0.5 specular albedo 0.05 roughness 0.03 brilliance 0.9 reflection { 0.007, 0.02 fresnel on } conserve_energy  
#if(useSubSurface)
      subsurface { translucency <1.09 1.59 1.79>*0.5 }  //0.9
#end

 }
 normal { crackle 1 scale 0.0115 turbulence 0.015 omega 0.7 lambda 5   } 
}


#macro getSplinePos(lSpline, currentPoint, nextDistance, stepSize)

#local pPos=currentPoint;      
#local totalLen = 0;
#local stepLen=0;
#while(stepLen <= nextDistance)
        #local pPos=pPos+stepSize;
        #if(pPos > 1.0)
            #local pPos=1.0;
            #break
        #end
        #local stepLen=vlength(lSpline(pPos)-lSpline(currentPoint));
//        #warning str(stepLen, 5, 5)
#end                                     
pPos

#end


#declare Strength = 1.0; //(+ or -) strength of component's radiating density



#macro mkSplineBinding(rad, spos, epos, tSpline, lRotation)
        #local lspos = spos;
        #local cRad = rad;
                #local tlen = 0.1;//tSpline(1)-tSpline(0); 
                
                #local noduleDist=epos/2;
                #local nodulePos=spos+rad*2;
                

                #while (lspos < epos)      
                   
              
                   #local Direction = (tSpline(lspos+0.001) -tSpline(lspos-0.001));   


                   sphere { 0, cRad, Strength scale <1, 0.75, 1>  
                   transform {Reorient_Trans(x,Direction)}   
                   translate <rad/4, 0, 0>
                   translate tSpline(lspos)  
                   rotate lRotation
                   }  

                   #local cRad=cRad*0.98;
                   #local lspos = getSplinePos(tSpline, lspos, cRad/6, 0.0001);  
                   

                #end 

                #local lspos=spos+0.1;
                #local cRad = rad*0.9;
                // add bumps
                #while (lspos < epos-0.01)      
                   
              
                   #local Direction = (tSpline(lspos+0.001) -tSpline(lspos-0.001));   


                   sphere { 0, cRad/8, Strength scale <1, 2.5, 1>
                   transform {Reorient_Trans(x,Direction)}   
                   translate <rad/4, cRad*0.6, 0> rotate <-4+gr(8), 0, 0>
                   //transform {Reorient_Trans(z,Direction)}   
                   translate tSpline(lspos)  
                   rotate lRotation        
                   texture  { starTexSpot } 
                   } 
                   

                   sphere { 0, cRad/8, Strength scale <0.75, 2.5, 0.75>  
                   transform {Reorient_Trans(x,Direction)}   
                   translate <rad/4, cRad*0.6, 0> rotate <-(86+gr(8)), 0, 0>
                   //transform {Reorient_Trans(z,Direction)}   
                   translate tSpline(lspos)  
                   rotate lRotation        
                   texture  { starTexSpot } 
                   }  
                   sphere { 0, cRad/8, Strength scale <0.5, 5.0, 0.5>  
                   transform {Reorient_Trans(x,Direction)}   
                   translate <rad/4, cRad*0.6, 0> rotate <-(86+gr(8)), 0, 0>
                   //transform {Reorient_Trans(z,Direction)}   
                   translate tSpline(lspos)  
                   rotate lRotation        
                   texture  { starTexSpot } 
                   }  

                   
                   sphere { 0, cRad/8, Strength scale <0.75, 2.5, 0.75>  
                   transform {Reorient_Trans(x,Direction)}   
                   translate <rad/4, cRad*0.6, 0> rotate <(86+gr(8)), 0, 0>
                   //transform {Reorient_Trans(z,Direction)}   
                   translate tSpline(lspos)  
                   rotate lRotation        
                   texture  { starTexSpot } 
                   }  
                   sphere { 0, cRad/8, Strength scale <0.5, 5.0, 0.5>  
                   transform {Reorient_Trans(x,Direction)}   
                   translate <rad/4, cRad*0.6, 0> rotate <(86+gr(8)), 0, 0>
                   //transform {Reorient_Trans(z,Direction)}   
                   translate tSpline(lspos)  
                   rotate lRotation        
                   texture  { starTexSpot } 
                   }  

                   

                   #local cRad=cRad*0.985;
                   #local lspos = getSplinePos(tSpline, lspos, cRad*0.2, 0.0001);  
                   

                #end 

                #local lspos=spos+0.1;
                #local cRad = rad*0.8;
                // add bumps
                #while (lspos < epos-0.01)      
                   
              
                   #local Direction = (tSpline(lspos+0.001) -tSpline(lspos-0.001));   



                   sphere { 0, cRad/7, Strength scale <1, 2.5, 1>  translate <rad/4, cRad*0.6, 0> rotate <20+gr(20), 0, 0>
                   //transform {Reorient_Trans(z,Direction)}   
                   translate tSpline(lspos)  
                   rotate lRotation        
                   texture  { starTexSpot } 
                   }  
                   sphere { 0, cRad/7, Strength scale <1, 2.5, 1>  translate <rad/4, cRad*0.6, 0> rotate <50+gr(20), 0, 0>
                   //transform {Reorient_Trans(z,Direction)}   
                   translate tSpline(lspos)  
                   rotate lRotation        
                   texture  { starTexSpot } 
                   }  

                   sphere { 0, cRad/7, Strength scale <1, 2.5, 1>  translate <rad/4, cRad*0.6, 0> rotate <-(50+gr(20)), 0, 0>
                   //transform {Reorient_Trans(z,Direction)}   
                   translate tSpline(lspos)  
                   rotate lRotation        
                   texture  { starTexSpot } 
                   }  
                   sphere { 0, cRad/7, Strength scale <1, 2.5, 1>  translate <rad/4, cRad*0.6, 0> rotate <-(20+gr(20)), 0, 0>
                   //transform {Reorient_Trans(z,Direction)}   
                   translate tSpline(lspos)  
                   rotate lRotation        
                   texture  { starTexSpot } 
                   }  

                   #local cRad=cRad*0.975;
                   #local lspos = getSplinePos(tSpline, lspos, cRad*0.4, 0.0001);  
                   

                #end 
                


                
                 
#end




#macro leg()

    #declare LegSpline =
    spline {
         natural_spline
/*
         0.00, <0, 0, 0>
         0.25, <0.25, -0.05, 0>
         0.6, <0.5, 0.05, 0> 
         0.75, <0.75, 0.0, 0> 
         1.0, <1.0, 0.05, 0.025>
*/
         0.00, <0, 0, 0>
         0.25, <0.25, 0.0, 0>
         0.6, <0.5, 0.025, 0> 
         0.75, <0.65, 0.1, 0> 
         1.0, <0.9, 0.175, 0.0>
    
       }

    #declare LegSpline2 =
    spline {
         natural_spline
         0.00, <0, 0, 0>
         0.25, <0.25, -0.05, 0>
         0.6, <0.5, 0.05, 0> 
         0.75, <0.75, 0.0, 0> 
         1.0, <1.0, 0.05, 0.025>
       }

    #declare LegSpline3 =
    spline {
         natural_spline
         0.00, <0, 0, 0>
         0.25, <0.25, -0.05, 0>
         0.6, <0.5, 0.0, 0> 
         0.75, <0.7, 0.05, 0> 
         1.0, <0.95, 0.15, 0.025>
       }

    #declare LegSpline4 =
    spline {
         natural_spline
         0.00, <0, 0, 0>
         0.25, <0.25, -0.05, 0>
         0.6, <0.5, 0.05, 0> 
         0.75, <0.75, 0.0, 0> 
         1.0, <1.0, 0.025, 0.025>
       }

    #declare LegSpline5 =
    spline {
         natural_spline
         0.00, <0, 0, 0>
         0.25, <0.15, -0.05, 0>
         0.6, <0.4, 0.05, 0> 
         0.75, <0.6, 0.0, 0.025> 
         1.0, <0.8, 0.125, 0.05>
       }


    blob{
        threshold 0.6 // threshold (0.0 < threshold <= Strength) surface falloff threshold #
                        
        mkSplineBinding(0.18, 0.0075+gr(0.0001), 1, LegSpline, <0, 0, 0>)                 
        mkSplineBinding(0.2, 0.0075+gr(0.0001), 1, LegSpline2, <0, -70, 0>)                 
        mkSplineBinding(0.2, 0.0075+gr(0.0001), 1, LegSpline3, <0, -150, 0>)                 
        mkSplineBinding(0.19, 0.0075+gr(0.0001), 1, LegSpline4, <0, -225, 0>)                 
        mkSplineBinding(0.2, 0.0075+gr(0.0001), 1, LegSpline5, <0, -305, 0>)                 
                    
                
        material { starTex }
                
       scale 4
        translate <-6, -0.2, 0>

       // double_illuminate
       }
 
  
#end

#if(showStar)

object {  leg() scale 0.3 rotate <-2, -40, 24> translate <5.1, -0.05, 2.0> }     
//sphere {  0, 3  rotate <-30, 0, 0> translate <2, 2, 5> 
//material { starTex }
//}     
#end

#if(useHDR)
sphere  { 0 1 hollow
  pigment{
    image_map{ hdr "Harbour_3_Ref.hdr"// "SM_HDRI-Pack3-14.hdr"  // was harbour   Harbour_3_Ref  Japan_blossom_FINAL
               
               map_type 1 interpolate 2}
      }// end pigment        
      finish { ambient 1 diffuse 1 emission 0.5 }
    scale 4000 // no_image
// rotate <0, -10, 0>   
// rotate <10, 0, 0>
// rotate <0, 140, 0>
 rotate <0, 260, 0>  // -140
// rotate <10, 0, -10>

} // end
#end     


// rock pool

#declare hf2func=function{pigment { average pigment_map { 
//[ 3 spherical poly_wave 2 colour_map { [ 0 rgb 1] [ 0.95 rgb 1 ] [ 1 rgb 0 ] }  scale 14 translate <0.5, 0, 0.5> ]
//[ 50 gradient -x poly_wave 50  scale <1.05, 1, 1> translate <-0.025, 0, 0.5> ]
//[ 50 gradient z poly_wave 50 scale <1, 1, 1.05> translate <0, 0, -0.025> ]
//[ 50 gradient -z poly_wave 50  scale <1, 1, 1.05> translate <0, 0, -0.025> ]   
//[ 0.1 wrinkles sine_wave turbulence 0.175 colour_map { [ 0 rgb 1]  [ 1 rgb 0 ] } scale 0.375  translate <-1, 0, 0.00> ]
[ 1 wrinkles cubic_wave turbulence 0.175 colour_map { [ 0 rgb 1]  [ 1 rgb 0 ] } scale 0.375  translate <-1, 0, 0.00> ]
//[ 0.25 granite turbulence 0.1275 scale .75 omega 0.65 lambda 2.75 translate <-0.7, 0, -0.4> ]
//[ .5 wrinkles poly_wave 10 turbulence 0.275 scale 0.5 translate <-0.7, 0, -0.4> ]

   } 
     }
   }
#declare land_tex_finish =         finish { ambient 0 diffuse albedo 0.5 specular  0.07 roughness 0.0035  brilliance 1.1 }
#declare land_tex_finish_damp =      finish { ambient 0 diffuse albedo 0.3 specular 0.4 roughness 0.001 brilliance 2.5 reflection { 0.01, 0.1 fresnel on } conserve_energy }
#declare land_tex_finish_wet =      finish { ambient 0 diffuse albedo 0.3 specular 0.075 roughness 0.001 brilliance 3 reflection { 0.01, 0.05 fresnel on } conserve_energy }
//#declare land_tex_finish_wet =      finish { ambient 0 diffuse albedo 0.3 specular 0.05 roughness 0.01  brilliance 3 reflection { 0.008, 0.02 fresnel on } conserve_energy }


#declare dryReduction=1;

#declare rock_base = texture
{
        pigment { granite triangle_wave omega 0.7 lambda 3 turbulence 0.275 
                color_map {  [ 0.0 rgb <0.295, 0.285, 0.27>*dryReduction ] [ 1.0 rgb <0.675, 0.6, 0.45>*dryReduction ] } 
                scale 1.75 
                }  
}


#declare land_tex_1 = texture
{   
        pigment 
        {
                crackle            
                turbulence 0.75 form <1, 0, 0>  
                omega 0.7 lambda 4
                scale 0.25     
                color_map
                {
                        [ 0.0 rgbt <0.82*dryReduction, 0.8*dryReduction, 0.785*dryReduction, 0.01> ] 
                        [ 0.2 rgbt <0.72*dryReduction, 0.7*dryReduction, 0.6*dryReduction, 0.1> ] 
                        [ 0.3 rgbt <0.72*dryReduction, 0.7*dryReduction, 0.6*dryReduction, 1> ] 
                        [ 0.3 rgbt 1 ]
                        [ 1.0 rgbt 1 ]
                }
        }


}      


#declare land_tex_2 = texture
{   
        pigment 
        {
                crackle            
                turbulence 0.75// metric 2 form <-2, 1, 0>
                omega 0.7 lambda 3
                scale .02     
                color_map
                {

                        [ 0.0 rgbt 1 ]
                        [ 0.3 rgbt 1 ]
                        [ 0.3 rgbt <0.2*dryReduction, 0.1*dryReduction, 0.05*dryReduction, 1> ] 
                        [ 0.5 rgbt <0.15*dryReduction, 0.1*dryReduction, 0.035*dryReduction, 0.3> ] 
                        [ 0.9 rgbt <0.2*dryReduction, 0.1*dryReduction, 0.05*dryReduction, 1> ] 
                        [ 0.9 rgbt 1 ]
                        [ 1.0 rgbt 1 ]
                }
        }

}

#declare land_tex_3 = texture
{   
        pigment 
        {
                wrinkles sine_wave           
                turbulence 0.65   
                omega 0.65 lambda 4
                scale 0.602
                color_map
                {
                        [ 0.0 rgbt 1 ]
                        [ 0.5 rgbt 1 ]
                        [ 0.5 rgbt <0.15*dryReduction, 0.09*dryReduction, 0.015*dryReduction, 1> ] 
                        [ 1.0 rgbt <0.15*dryReduction, 0.09*dryReduction, 0.015*dryReduction, 0.7> ] 
                 }
        }


}  


#declare land_tex_4 = texture
{   
        pigment 
        {
                granite sine_wave     
                turbulence 0.45   
                omega 0.65 lambda 4
                scale 1.3
                color_map
                {
                        [ 0.0 rgbt 1 ]
                        [ 0.65 rgbt 1 ]
                        [ 0.65 rgbt <0.15*dryReduction, 0.09*dryReduction, 0.015*dryReduction, 1> ] 
                        [ 1.0 rgbt <0.15*dryReduction, 0.09*dryReduction, 0.015*dryReduction, 0.5> ] 
                 }
        }


}

#declare land_tex_5 = texture
{   
        pigment 
        {
                granite sine_wave           
                turbulence 0.45   
                omega 0.85 lambda 2.7
                scale 0.6
                color_map
                {
                        [ 0.0 rgbt 1 ]
                        [ 0.7 rgbt 1 ]
                        [ 0.7 rgbt <0.045*dryReduction, 0.155*dryReduction, 0.004*dryReduction, 1> ] 
                        [ 1.0 rgbt <0.045*dryReduction, 0.155*dryReduction, 0.004*dryReduction, 0.5> ] 
                 }                   
        }
        finish { land_tex_finish }

}


#declare land_tex_dry = texture
{
        rock_base
}      
texture
{
        land_tex_1
}
texture
{
        land_tex_2
}
texture
{
        land_tex_3
}
texture
{
        land_tex_4
} 
texture
{
        land_tex_5
} 



            

// damp textures

#declare dampReduction=0.52;


#declare rock_base_damp = texture
{
        pigment { granite triangle_wave omega 0.7 lambda 3 turbulence 0.275 
                color_map {  [ 0.0 rgb <0.295, 0.25, 0.21>*dampReduction ] [ 1.0 rgb <0.675, 0.45, 0.2>*dampReduction ] } 
                scale 1.75 
                }
}




#declare land_tex_1_damp = texture
{   
        pigment 
        {
                crackle            
                turbulence 0.75 form <1, 0, 0>  
                omega 0.7 lambda 4
                scale 0.25     
                color_map
                {
                        [ 0.0 rgbt <0.82*dampReduction, 0.7*dampReduction, 0.585*dampReduction, 0.01> ] 
                        [ 0.2 rgbt <0.72*dampReduction, 0.6*dampReduction, 0.4*dampReduction, 0.1> ] 
                        [ 0.3 rgbt <0.72*dampReduction, 0.6*dampReduction, 0.4*dampReduction, 1> ] 
                        [ 0.3 rgbt 1 ]
                        [ 1.0 rgbt 1 ]
                }
        }


}      


#declare land_tex_2_damp = texture
{   
        pigment 
        {
                crackle            
                turbulence 0.75// metric 2 form <-2, 1, 0>
                omega 0.7 lambda 3
                scale .02     
                color_map
                {

                        [ 0.0 rgbt 1 ]
                        [ 0.3 rgbt 1 ]
                        [ 0.3 rgbt <0.2*dampReduction, 0.071*dampReduction, 0.035*dampReduction, 1> ] 
                        [ 0.5 rgbt <0.15*dampReduction, 0.071*dampReduction, 0.0135*dampReduction, 0.3> ] 
                        [ 0.9 rgbt <0.2*dampReduction, 0.071*dampReduction, 0.035*dampReduction, 1> ] 
                        [ 0.9 rgbt 1 ]
                        [ 1.0 rgbt 1 ]
                }
        }


}

#declare land_tex_3_damp = texture
{   
        pigment 
        {
                wrinkles sine_wave           
                turbulence 0.65   
                omega 0.65 lambda 4
                scale 0.602
                color_map
                {
                        [ 0.0 rgbt 1 ]
                        [ 0.5 rgbt 1 ]
                        [ 0.5 rgbt <0.15*dampReduction, 0.069*dampReduction, 0.01*dampReduction, 1> ] 
                        [ 1.0 rgbt <0.15*dampReduction, 0.069*dampReduction, 0.01*dampReduction, 0.7> ] 
                 }
        }


}  


#declare land_tex_4_damp = texture
{   
        pigment 
        {
                granite sine_wave     
                turbulence 0.45   
                omega 0.65 lambda 4
                scale 1.3
                color_map
                {
                        [ 0.0 rgbt 1 ]
                        [ 0.65 rgbt 1 ]
                        [ 0.65 rgbt <0.15*dampReduction, 0.069*dampReduction, 0.01*dampReduction, 1> ] 
                        [ 1.0 rgbt <0.15*dampReduction, 0.069*dampReduction, 0.01*dampReduction, 0.5> ] 
                 }
        }


}

#declare land_tex_5_damp = texture
{   
        pigment 
        {
                granite sine_wave           
                turbulence 0.45   
                omega 0.85 lambda 2.7
                scale 0.6
                color_map
                {
                        [ 0.0 rgbt 1 ]
                        [ 0.7 rgbt 1 ]
                        [ 0.7 rgbt <0.025*dampReduction, 0.155*dampReduction, 0.004*dampReduction, 1> ] 
                        [ 1.0 rgbt <0.025*dampReduction, 0.155*dampReduction, 0.004*dampReduction, 0.5> ] 
                 }                   
        }
    finish { land_tex_finish_damp }
}



#declare land_tex_damp = texture
{
        rock_base_damp
}      
texture
{
        land_tex_1_damp
}
texture
{
        land_tex_2_damp
}
texture
{
        land_tex_3_damp
}
texture
{
        land_tex_4_damp
}
texture
{
        land_tex_5_damp
}

#declare wetReduction=0.45;

// wet textures 

#declare rock_base_wet = texture
{
        pigment { granite triangle_wave omega 0.7 lambda 3 turbulence 0.275 
                color_map {  [ 0.0 rgb <0.295, 0.25, 0.21>*wetReduction ] [ 1.0 rgb <0.675, 0.45, 0.2>*wetReduction ] } 
                scale 1.75 
                }
}



#declare land_tex_1_wet = texture
{   
        pigment 
        {
                crackle            
                turbulence 0.75 form <1, 0, 0>  
                omega 0.7 lambda 4
                scale 0.25     
                color_map
                {
                        [ 0.0 rgbt <0.82*wetReduction, 0.7*wetReduction, 0.585*wetReduction, 0.01> ] 
                        [ 0.2 rgbt <0.72*wetReduction, 0.6*wetReduction, 0.4*wetReduction, 0.1> ] 
                        [ 0.3 rgbt <0.72*wetReduction, 0.6*wetReduction, 0.4*wetReduction, 1> ] 
                        [ 0.3 rgbt 1 ]
                        [ 1.0 rgbt 1 ]
                }
        }


}      


#declare land_tex_2_wet = texture
{   
        pigment 
        {
                crackle            
                turbulence 0.75// metric 2 form <-2, 1, 0>
                omega 0.7 lambda 3
                scale .02     
                color_map
                {

                        [ 0.0 rgbt 1 ]
                        [ 0.3 rgbt 1 ]
                        [ 0.3 rgbt <0.2*wetReduction, 0.071*wetReduction, 0.035*wetReduction, 1> ] 
                        [ 0.5 rgbt <0.15*wetReduction, 0.071*wetReduction, 0.0135*wetReduction, 0.3> ] 
                        [ 0.9 rgbt <0.2*wetReduction, 0.071*wetReduction, 0.035*wetReduction, 1> ] 
                        [ 0.9 rgbt 1 ]
                        [ 1.0 rgbt 1 ]
                }
        }


}

#declare land_tex_3_wet = texture
{   
        pigment 
        {
                wrinkles sine_wave           
                turbulence 0.65   
                omega 0.65 lambda 4
                scale 0.602
                color_map
                {
                        [ 0.0 rgbt 1 ]
                        [ 0.5 rgbt 1 ]
                        [ 0.5 rgbt <0.15*wetReduction, 0.069*wetReduction, 0.01*wetReduction, 1> ] 
                        [ 1.0 rgbt <0.15*wetReduction, 0.069*wetReduction, 0.01*wetReduction, 0.7> ] 
                 }
        }
}  


#declare land_tex_4_wet = texture
{   
        pigment 
        {
                granite sine_wave     
                turbulence 0.45   
                omega 0.65 lambda 4
                scale 1.3
                color_map
                {
                        [ 0.0 rgbt 1 ]
                        [ 0.65 rgbt 1 ]
                        [ 0.65 rgbt <0.15*wetReduction, 0.069*wetReduction, 0.01*wetReduction, 1> ] 
                        [ 1.0 rgbt <0.15*wetReduction, 0.069*wetReduction, 0.01*wetReduction, 0.5> ] 
                 }
        }


}

#declare land_tex_5_wet = texture
{   
        pigment 
        {
                granite sine_wave           
                turbulence 0.45   
                omega 0.85 lambda 2.7
                scale 0.6
                color_map
                {
                        [ 0.0 rgbt 1 ]
                        [ 0.7 rgbt 1 ]
                        [ 0.7 rgbt <0.025*wetReduction, 0.155*wetReduction, 0.004*wetReduction, 1> ] 
                        [ 1.0 rgbt <0.025*wetReduction, 0.155*wetReduction, 0.004*wetReduction, 0.5> ] 
                 }                   
        }
        finish { land_tex_finish_wet }

}


#declare land_tex_wet = texture
{
        rock_base_wet
}      
texture
{
        land_tex_1_wet
}
texture
{
        land_tex_2_wet
}
texture
{
        land_tex_3_wet
}
texture
{
        land_tex_4_wet
}
texture
{
        land_tex_5_wet
} 


 #if(useTestTex)
#declare land_tex_dry = texture
{
       rock_base
  // pigment { rgb <1, 0, 0> } 
}      
#declare land_tex_damp = texture
{
      rock_base_damp  
  //     pigment { rgb <0, 1, 0> } 
}

#declare land_tex_wet = texture
{
      rock_base_wet  
  //     pigment { rgb <0, 0, 1> } 
}
#end 

//#declare  rockTexWet = texture { pigment { rgb <0, 0, 1> } }
//#declare  rockTexDamp = texture { pigment { rgb <0, 1, 0> } }
//#declare  rockTex = texture { pigment { rgb <1, 0, 0> } }
         

#declare land_tex = texture 
{
        gradient y  triangle_wave          
//        turbulence 0.275
//        omega 0.526 lambda 2.5 
        texture_map 
        {
                [ 0.0  land_tex_wet ]// scale 0.2 ]
                [ 0.5  land_tex_wet ]// scale 0.2 ]
                [ 0.5  land_tex_damp ]// scale 0.2 ]
                [ 0.55  land_tex_damp ]// scale 0.2 ]
                [ 0.65  land_tex_dry ]// scale 0.2 ]
                [ 1.0  land_tex_dry ]// scale 0.2 ]
         }   
         scale 5   
         turbulence 0.025
         translate <0, -1.475, 0>
}



#if(showWater)  


// water
box { <-135, -15, -135> <135, -0.2, 135> hollow  // was 0.15 y

#if(useTestTex) 
material {
texture {
pigment { rgbt <0.98, 0.99, 0.98, 0.99> }      
normal { average normal_map { [ 1 ripples 0.05 frequency 4 scale 0.5 omega 0.7 turbulence 0.5] [ 0.5 bumps 0.1 scale 0.5 turbulence 0.2 ] } }
finish { specular albedo 0.4 roughness 0.005 diffuse albedo 0.05 brilliance 4 ambient 0 reflection { 0.05, 0.75  fresnel on } conserve_energy }     
}
  interior {
    ior 1.35              // index of refraction
    caustics 1.0          // faked caustics (0..1)
    fade_power 1001    // values larger than 1000 give realistic exponential attenuation
    fade_distance 1.0    // distance where light reaches half intensity
    fade_color <0, 0.4, 0.3> // color for fading        
 /*
    media {absorption <.4, 0.13, 0.12>*0.5 
    scattering { 1 0.2 } method 3   
      density { wrinkles scale 0.2
        warp { turbulence <0.25, 0.55, 0.25> lambda 2.6  omega 0.54 octaves 10  }
        density_map {
          [0.25 rgb <0,0,0>]
          [1 rgb 1] }
      }
      }
     */
}
}

#else 
material {
texture {
pigment { rgbt <0.98, 0.99, 0.98, 0.99> }//.05 was value                                                       // was 0.5
normal { average normal_map { [ 1 ripples 0.1 frequency 4 scale 0.5 omega 0.7 turbulence 0.5] [ 0.5 bumps 0.1 scale 0.35 turbulence 0.2 ] } }
finish { specular albedo 0.4 roughness 0.005 diffuse albedo 0.03 brilliance 4 ambient 0 reflection { 0.05, 0.95  fresnel on } conserve_energy }     
}
  interior {
    ior 1.35              // index of refraction
    caustics 1.0          // faked caustics (0..1)
    fade_power 1001    // values larger than 1000 give realistic exponential attenuation
    fade_distance 1.0    // distance where light reaches half intensity
    fade_color <0, 0.4, 0.3> // color for fading        
 
/*
  media {absorption <.4, 0.13, 0.12>*0.5 
    scattering { 1 0.2 } method 3   
      density { wrinkles scale 0.2
        warp { turbulence <0.25, 0.55, 0.25> lambda 2.6  omega 0.54 octaves 10  }
        density_map {
          [0.25 rgb <0,0,0>]
          [1 rgb 1] }
      }
      }
*/     
}
} 

#end

#if(usePhotons)
  photons {
    target 1
    reflection on
    refraction on
    collect off        
  }
  #end
}

#end




// stone
#declare stoneFinish = finish {

    diffuse albedo 0.6         // ambient surface reflection color [0.1] 
    brilliance 1.6
    specular 0.025 roughness 0.15
//    phong albedo 0.125          // amount [0.0]
//    phong_size 30      // (1.0..250+) (dull->highly polished) [40]
  } 

#declare stoneFinishDamp = finish {
                      
    diffuse albedo 0.3         // ambient surface reflection color [0.1] 
    brilliance 3.0
    specular 0.4 roughness 0.002
    phong 0.1          // amount [0.0]
    phong_size 90      // (1.0..250+) (dull->highly polished) [40]   
    reflection { 0.01, 0.5 fresnel on } conserve_energy
  } 

#declare stoneFinishWet = finish {
                      
    diffuse albedo 0.3         // ambient surface reflection color [0.1] 
    brilliance 3.0
    specular  0.0 
    phong  0.0          // amount [0.0]
  } 



#declare fn_scallop_ripples=function { pigment {
        ripples          
        scallop_wave
        turbulence 0.5
        omega 0.5
        lambda 5
        colour_map
        {
                [ 0.0 rgb 0.5 ]
                [ 0.9 rgb 0.5 ]
                [ 0.92 rgb 1 ]
                [ 0.94 rgb 1 ]
                [ 1.0 rgb 0.5 ]
                
        }  
        scale <0.25, 0.6, 0.15>
}

}

#declare stoneWetRed=0.3;

#declare stoneTex = texture
{        
        pigment 
        {  
                agate  
                lambda 4
                omega 0.8565
                agate_turb 0.375
                colour_map
                {
                        [ 0.0 rgb <1, 1, 1>*0.75 ]
                        [ 0.2 rgb <1, 0.8, 0.5>*0.75 ]
                        [ 0.5 rgb <0.9, 0.85, 0.7>*0.75 ]
                        [ 0.51 rgb <0.3, 0.3, 0.225>*0.75 ]
                        [ 0.55 rgb <0.25, 0.25, 0.175>*0.75 ]
                        [ 0.56 rgb <0.8, 0.8, 0.69>*0.75 ]
                        [ 0.9 rgb <0.9, 0.7, 0.495>*0.75 ]
                        [ 1.0 rgb <1, 1, 1>*0.5 ]
                }
                scale <1.65, 1.4, 1.5>
        }         
        finish { stoneFinish }
}               

#declare stoneTexDamp = texture
{        
        pigment 
        {  
                agate  
                lambda 4
                omega 0.8565
                agate_turb 0.375
                colour_map
                {
                        [ 0.0 rgb <1, 1, 1>*0.5 ]
                        [ 0.2 rgb <1, 0.8, 0.5>*stoneWetRed ]
                        [ 0.5 rgb <0.9, 0.85, 0.7>*stoneWetRed ]
                        [ 0.51 rgb <0.3, 0.3, 0.225>*stoneWetRed ]
                        [ 0.55 rgb <0.25, 0.25, 0.175>*stoneWetRed ]
                        [ 0.56 rgb <0.8, 0.8, 0.69>*stoneWetRed ]
                        [ 0.9 rgb <0.9, 0.7, 0.495>*stoneWetRed ]
                        [ 1.0 rgb <1, 1, 1>*stoneWetRed ]
                }
                scale <1.65, 1.4, 1.5>
        }         
        finish { stoneFinishDamp }
}               

#declare stoneTexWet = texture
{        
        pigment 
        {  
                agate  
                lambda 4
                omega 0.8565
                agate_turb 0.375
                colour_map
                {
                        [ 0.0 rgb <1, 1, 1>*stoneWetRed ]
                        [ 0.2 rgb <1, 0.8, 0.5>*stoneWetRed ]
                        [ 0.5 rgb <0.9, 0.85, 0.7>*stoneWetRed ]
                        [ 0.51 rgb <0.3, 0.3, 0.225>*stoneWetRed ]
                        [ 0.55 rgb <0.25, 0.25, 0.175>*stoneWetRed ]
                        [ 0.56 rgb <0.8, 0.8, 0.69>*stoneWetRed ]
                        [ 0.9 rgb <0.9, 0.7, 0.495>*stoneWetRed ]
                        [ 1.0 rgb <1, 1, 1>*stoneWetRed ]
                }
                scale <1.65, 1.4, 1.5>
        }         
        finish { stoneFinishWet }
}               

//#declare stoneTexWet=texture { pigment { rgb <0, 0, 1> } }
//#declare stoneTexDamp=texture { pigment { rgb <0, 1, 0> } }
//#declare stoneTex=texture { pigment { rgb <1, 0, 0> } }

#declare  S = function { sqrt(pow(x,2) + pow(y,2) + pow(z,2)) - 2 }                      

#if(showStone)

#declare tStone1Wet = texture  {
pigment {
        wrinkles          
        triangle_wave
        turbulence 0.55
        omega 0.85
        lambda 3
        colour_map
        {
                [ 0.0 rgb <1, 0.99, 0.96>*0.75 ]
                [ 0.2 rgb <1, 0.96, 0.9>*0.45 ]
                [ 0.4 rgb <1, 0.965, 0.96>*0.55 ]
                [ 0.7 rgb <1, 0.99, 0.99>*0.35 ]
                [ 1.0 rgb <1, 0.95, 0.95>*0.75 ]
                
        }  
        scale <0.75, 1.2, 0.5>
        }                
}
texture
{
        pigment {
        ripples          
        scallop_wave
        turbulence 0.5
        omega 0.55
        lambda 5
        colour_map
        {
                [ 0.0 rgbt <1, 1, 1, 1> ]
                [ 0.9 rgbt <1, 1, 1, 1> ]
                [ 0.92 rgbt <0.2, 0.17, 0.12, 0.5> ]
                [ 0.94 rgbt <0.1, 0.072, 0.05, 0.2> ]
                [ 1.0 rgbt <1, 1, 1, 1> ]
                
        }
        scale <0.25, 0.6, 0.15>
        }
        finish { stoneFinishDamp }
}

#declare tStone1Dry = texture  {
pigment {
        wrinkles          
        triangle_wave
        turbulence 0.55
        omega 0.85
        lambda 3
        colour_map
        {
                [ 0.0 rgb <1, 0.99, 0.96>*0.75 ]
                [ 0.2 rgb <1, 0.96, 0.9>*0.45 ]
                [ 0.4 rgb <1, 0.965, 0.96>*0.55 ]
                [ 0.7 rgb <1, 0.99, 0.99>*0.35 ]
                [ 1.0 rgb <1, 0.95, 0.95>*0.75 ]
                
        }  
        scale <0.75, 1.2, 0.5>
        }                
}
texture
{
        pigment {
        ripples          
        scallop_wave
        turbulence 0.5
        omega 0.55
        lambda 5
        colour_map
        {
                [ 0.0 rgbt <1, 1, 1, 1> ]
                [ 0.9 rgbt <1, 1, 1, 1> ]
                [ 0.92 rgbt <0.2, 0.17, 0.12, 0.5> ]
                [ 0.94 rgbt <0.1, 0.072, 0.05, 0.2> ]
                [ 1.0 rgbt <1, 1, 1, 1> ]
                
        }
        scale <0.25, 0.6, 0.15>
        }
        finish { stoneFinish }
}

#declare Stone1 = isosurface {
  function { S(x,y*(1.5-y/12),z)-f_wrinkles(x*0.3,y*0.5,z*0.03)*0.05-fn_scallop_ripples(x,y,z).gray*0.001-f_wrinkles(x*3,y*4,z*4)*0.005-f_crackle(x*15, y*15, z*15)*0.01 }
        accuracy isoAccuracy               
        max_gradient 2.75
        contained_by{sphere{0,2.2}}   
        
rotate <0, 0, 90>   
scale <1, 0.6, 1>*0.3   
rotate <0, 50, -45>
translate <0.0, -0.2, 0.1>

        
#if(useTestTex)
        texture { pigment {rgb 0.6} }
#else
material {
texture {
gradient y texture_map { 
[ 0.0 tStone1Wet ]
[ 0.5 tStone1Dry ]
}  
translate <0, -0.5, 0>
}
interior { ior 1.6 }  
}
#end
        
}


#declare Stone5 = isosurface {
//  function { S(x*(1.5-x/15),y*(1.05-y/30),z)-f_ripples(x*0.75,y*0.75,z*0.6)*0.5-f_wrinkles(x*5,y*3,z*2)*0.0075-fn_scallop_ripples(x*0.5,y*0.5,z*0.5).gray*0.002}  
  function { S(x*(1.5-x/15),y*(1.05-y/30),z)-f_ripples(x*0.75,y*0.75,z*0.6)*0.6-fn_scallop_ripples(x*0.015,y*0.015,z*0.015).gray*0.05-f_crackle(x*15, y*15, z*15)*0.0095}  
        accuracy isoAccuracy              
        max_gradient 2.45
        contained_by{sphere{0,2.55}}  
rotate <0, 0, 90>   
scale <1, 0.35, 1.2>*0.35   
rotate <15, -75, 15>
translate <-0.95, -0.025, 0.0>

#if(useTestTex)
        texture { pigment { rgb 0.7 } }
#else
texture
{ 
    gradient y     
    triangle_wave 
    turbulence 0.02 
    texture_map
        {  
//            [ 0.0 stoneTexWet scale 0.5 ]
//            [ 0.25 stoneTexWet scale 0.5 ]
//            [ 0.26 stoneTexDamp scale 0.5 ]
//            [ 0.28 stoneTexDamp scale 0.5 ]
            [ 0.35 stoneTex scale 0.5 ]            
        }                    
        scale 2 
        translate <0, -0.2, 0>
}               
#end
}

object { Stone1 }     
object { Stone5 }     


#end   


 
#declare F=function{pigment{
  crackle  
  form <-0.5, 0.5, -0.0015>
  turbulence 0.1
  color_map { [0.0 rgb 1] [1 rgb 0] }
  scale 0.8
  }
} 


#declare rock1 = isosurface {
//  function { S(x*(1.5-x/15),y*(1.05-y/30),z)-f_ripples(x*0.75,y*0.75,z*0.6)*0.5-f_wrinkles(x*5,y*3,z*2)*0.0075-fn_scallop_ripples(x*0.5,y*0.5,z*0.5).gray*0.002}  
//  function { S(x*(1.5-x/15),y*(1.05-y/30),z)-f_ripples(x*0.75,y*0.75,z*0.6)*0.6-fn_scallop_ripples(x*0.015,y*0.015,z*0.015).gray*0.05-f_crackle(x*15, y*15, z*15)*0.0095}  
  function { S(x*(0.75-x/5),y*(1.05-y/10),z*(0.5-z/2))+F(x,y,z).grey*0.3 }  
        accuracy isoAccuracy              
        max_gradient 2.85
        contained_by{sphere{0,5.55}}  

texture
{ 
    pigment {   crackle  
  form <-0.5, 0.5, -0.0015>
  turbulence 0.1
  color_map { [0.0 rgb <0.25, 0.15, 0.05>] [0.005 rgb 0.6]  [1 rgb 0.6] }
  scale 0.8
  
  }
    finish { diffuse albedo 0.5 specular albedo 0.01 roughness 0.15 }
}
scale 3
             
translate <-1, -5.15, 4>
}

//object { rock1 translate <0, 0, 4>}
//object { rock1 rotate <40, 0, 0> translate <0, -2, 3> }





#declare rock_base = texture
{
        pigment { granite triangle_wave omega 0.6 lambda 3 turbulence 0.275 
                color_map {  [ 0.0 rgb <0.175, 0.175, 0.175> ] [ 1.0 rgb <0.425, 0.425, 0.425> ] } 
                scale 0.25 
                }
        finish { ambient 0 diffuse 0.5 }
}

#declare rock_tex_1 = texture
{   
        pigment 
        {
                wrinkles            
                turbulence 0.1   
                omega 0.7 lambda 4
                color_map
                {
                        [ 0.0 rgbt <1, 1, 1, 1> ]// rgbt <0.15, 0.09, 0.015, 0.05> ] 
                        [ 0.5 rgbt <1, 1, 1, 1> ]// rgbt <0.15, 0.09, 0.015, 0.05> ] 
                        [ 0.5 rgbt <0.15, 0.09, 0.015, 1> ] //rgbt 1 ]
                        [ 0.8 rgbt <0.15, 0.09, 0.015, 0.25> ] //rgbt 1 ]
                        [ 1.0 rgbt <0.15, 0.091, 0.015, 0.1> ] //rgbt 1 ]
                }                         
                scale 25
        }
        finish { ambient 0 diffuse 0.45 specular 0 phong 0 }
}          

#declare rock_tex_2 = texture
{   
        pigment 
        {
                wrinkles  
                scallop_wave          
                turbulence 0.1   
                omega 0.7 lambda 4
                color_map
                {
                        [ 0.0 rgbt <0.15, 0.09, 0.015, 0.1> ] //rgbt 1 ]
                        [ 0.5 rgbt <0.15, 0.09, 0.015, 0.5> ] //rgbt 1 ]
                        [ 0.75 rgbt <0.15, 0.091, 0.015, 1> ] //rgbt 1 ]
                        [ 0.75 rgbt <1, 1, 1, 1> ]// rgbt <0.15, 0.09, 0.015, 0.05> ] 
                        [ 1.0 rgbt <1, 1, 1, 1> ]// rgbt <0.15, 0.09, 0.015, 0.05> ] 
                }                         
                scale 15
        }
        finish { ambient 0 diffuse 0.45 specular 0 phong 0 }


}          

#declare rock_tex_3 = texture
{   
        pigment 
        {
                bozo scallop_wave           
                turbulence 0.7 
                omega 0.7 lambda 4 octaves 10 
                scale 0.56
                color_map
                {
                        [ 0.0 rgbt 1 ]
                        [ 0.9 rgbt 1 ]
                        [ 0.925 rgbt <0.0075, 0.06, 0.0005, 1> ] 
                        [ 0.975 rgbt <0.0075, 0.06, 0.0005, 0.4> ] 
                        [ 1.0 rgbt <0.0075, 0.06, 0.0005, 0> ] 
                 }
        } 
        finish { ambient 0 diffuse 0.5 specular 0 phong 0 }
        scale 20


}
#declare rock_tex_4 = texture
{   
        pigment 
        {
                granite            
                turbulence 0.2 
                omega 0.6 lambda 2.5 
                color_map
                {
                        [ 0.0 rgbt 1 ]
                        [ 0.1 rgbt 1 ]
                        [ 0.15 rgbt <0.1, 0.06, 0.01, 1> ] 
                        [ 0.3 rgbt <0.1, 0.06, 0.01, 0.1> ] 
                        [ 0.45 rgbt <0.1, 0.06, 0.01, 1> ] 
                        [ 0.5 rgbt 1 ]
                        [ 0.6 rgbt 1 ]
                        [ 0.65 rgbt <0.0075, 0.06, 0.0005, 1> ] 
                        [ 0.75 rgbt <0.0075, 0.06, 0.0005, 0.05> ] 
                        [ 0.9 rgbt <0.0075, 0.06, 0.0005, 1> ] 
                        [ 0.95 rgbt 1 ]
                        [ 1.0 rgbt 1 ]
                 }
                scale 0.1
        }          
        finish { ambient 0 diffuse 0.45 specular 0 phong 0 }


}


#declare rock_tex_dry = texture
{
       rock_base scale 10
}
texture
{
        rock_tex_1
}
texture
{
        rock_tex_2
}
texture
{
        rock_tex_3
}
texture
{
        rock_tex_4
        finish { ambient 0 diffuse 0.45 specular 0 phong 0 }
}
/*
texture
{
        rock_tex_5
}  
*/

#declare rock_tex_wet = texture
{
       rock_base scale 10
}
texture
{
        rock_tex_1
}
texture
{
        rock_tex_2
}
texture
{
        rock_tex_3
}
texture
{
        rock_tex_4
        finish { ambient 0 diffuse 0.35 specular 0.5 roughness 0.001 phong 0.5 phong_size 150 }
}
/*
texture
{
//        rock_tex_5
}
*/

#declare rock_tex = texture 
{
        gradient y    
        scale 5        
        texture_map 
        {
                [ 0.0 rock_tex_wet scale 0.01 ]
                [ 0.5 rock_tex_wet scale 0.01 ]
                [ 0.55 rock_tex_dry scale 0.01 ]
                [ 1.0 rock_tex_dry scale 0.01 ]
         }   
         translate <0, -1.45, 0>
}






#declare t1 = texture {
pigment { granite scallop_wave omega 0.82 lambda 2.3 turbulence 0.45 colour_map { 
            [ 0.0 rgb <0.03, 0.03, 0.05> ]
            [ 0.3 rgb <0.025, 0.025, 0.03> ]
            [ 0.8 rgb <0.04, 0.04, 0.05> ]
            [ 1.0 rgb <.0225, 0.0265, 0.02> ]
            
         }
        }      
}    
texture {
pigment { wrinkles scallop_wave  omega 0.8 lambda 2.7 turbulence 0.175 colour_map { 
            [ 0.0 rgbt <1, 1, 1, 1> ]
            [ 0.5 rgbt <1, 1, 1, 1> ]
            [ 0.5 rgbt <0.015, 0.035, 0.004, 1> ]
            [ 0.51 rgbt <0.015, 0.035, 0.004, 0.2> ]
            [ 0.52 rgbt <0.015, 0.025, 0.004, 0.05> ]
            [ 0.53 rgbt <0.015, 0.035, 0.004, 0.05> ]
            [ 0.54 rgbt <0.04, 0.04, 0.004, 1> ]
            [ 0.54 rgbt <1, 1, 1, 1> ]
            [ 1.0 rgbt <1, 1, 1, 1> ]
            
         }
          scale 0.5
        }
}              
texture {
pigment {
            crackle     
            scallop_wave
            turbulence 0.025
            lambda 3.1
            omega 0.6255
            octaves 9
            colour_map {
                [ 0.0 rgbt 1 ]
                [ 0.5 rgbt 1 ]
                [ 0.5 rgbt <1.0, 0.7, 0.3, 1> ]
                [ 0.505 rgbt <1.0, 0.7, 0.3, 0.05> ]
                [ 0.51 rgbt <1.0, 0.7, 0.3, 0.05> ]
                [ 0.515 rgbt <0.8, 0.9, 0.6, 0.01> ]
                [ 0.52 rgbt <0.8, 0.9, 0.7, 0.01> ]
                [ 0.5225 rgbt <0.8, 0.9, 0.6, 1> ]
                [ 0.5225 rgbt 1 ]
                [ 1.0 rgbt 1 ]
            }        
            scale 1.25  
            translate <-0.2, 0.1, 0> 
         }
} 
texture {
pigment {
            granite 
            turbulence 0.075
            lambda 3.1
            omega 0.655
            octaves 9
            colour_map {
                [ 0.0 rgbt 1 ]
                [ 0.7 rgbt 1 ]
                [ 0.7 rgbt <1.0, 0.7, 0.3, 1> ]
                [ 0.71 rgbt <1.0, 0.7, 0.3, 0.05> ]
                [ 0.75 rgbt <1.0, 0.7, 0.3, 0.05> ]
                [ 0.76 rgbt <0.8, 0.9, 0.6, 0.01> ]
                [ 0.8 rgbt <0.8, 0.9, 0.7, 0.01> ]
                [ 0.81 rgbt <0.8, 0.9, 0.6, 1> ]
                [ 0.81 rgbt 1 ]
                [ 1.0 rgbt 1 ]
            }        
            scale 0.45
         }
} 
texture {
pigment { bozo  colour_map { [ 0.0 rgbf <0.98, 0.99, 0.98, 0.99> ] [ 1.0 rgbf 1 ] } scale 0.5 
}
normal { granite 0.1 scale 0.0001 }              
finish { specular albedo 0.1 roughness 0.025 ambient 0 diffuse albedo 0.2 brilliance 4 reflection { 0.01 0.15 fresnel on } conserve_energy   }
} 


#declare t1Wet = texture { t1 }
texture {
pigment { bozo omega 0.8 lambda 2.5 turbulence 0.25 colour_map { [ 0.0 rgbf <0.5, 0.65, 0.5, 0.9> ] [ 1.0 rgbf 1 ] } scale <0.05, 0.15, 0.05> 
}
normal { granite 0.2 scale 0.001 }              
finish { specular albedo 0.05 roughness 0.025 ambient 0 diffuse albedo 0.1 brilliance 8 reflection { 0.01 0.4 fresnel on } conserve_energy   }
} 

#declare land_tex_t1 = texture 
{
        gradient y  triangle_wave          
//        turbulence 0.275
//        omega 0.526 lambda 2.5 
        texture_map 
        {
                [ 0.0  t1Wet ]// scale 0.2 ]
                [ 0.5  t1Wet ]// scale 0.2 ]
                [ 0.60  t1 ]// scale 0.2 ]
                [ 1.0  t1 ]// scale 0.2 ]
         }   
         scale 5   
         turbulence 0.0125
         translate <0, -1.475, 0>
}





  #declare fn_rock_1=function {
    pigment {                              
      wrinkles    
      turbulence 0.1  
        
      colour_map
      {     
        [ 0 rgb 0 ]
        [ 1 rgb 1 ]
      }               
         
  
  }

} 

  #declare fn_rock_2=function {
    pigment {                              
      wrinkles    
      scallop_wave
      turbulence 0.1  
        
      colour_map
      {     
        [ 0 rgb 0 ]
        [ 1 rgb 1 ]
      }               
         
  
  }

}  

  #declare fn_rock_3=function {
    pigment {                              
      marble    
      scallop_wave
      turbulence 0.1  
      
      
        
      colour_map
      {     
        [ 0.0 rgb 0.01 ]
        [ 0.1 rgb 0.0 ]
        [ 0.25 rgb 0.1 ]
        [ 1 rgb 1 ]
      } 
      translate <0.15, 0, 0>              
         
  
  }

} 

  #declare fn_rock_4=function {
    pigment {                              
      granite    
      omega 0.8 lambda 2.2 turbulence 1 scale 0.65/5      
      
        
      colour_map
      {     
        [ 0.0 rgb 0.01 ]
        [ 1 rgb 1 ]
      }         
  
  }

} 



// Rock objects

#declare largeBackRock=isosurface 
{
        function{f_rounded_box(x,y,z, 0.1, 0.8, 0.2, 0.45)-(fn_rock_2(x*1,y*1,z*1).grey*0.2)-(fn_rock_1(x*1,y*1.5,z*1.25).grey*0.1)}
//        function{f_sphere(x,y,z, rsize)-(fn_rock_2(x*0.1,y*0.1,z*0.1).grey*8)}
        threshold 0
        contained_by {box { <-1.05, -0.5, -0.75> <1.05, 0.5, 0.75> } }
        accuracy isoAccuracy
        max_gradient 4.411  
        scale 8     
        
       
}  

#declare largeBackRock1 = object { largeBackRock rotate <-10, 20, 0> translate <-3.5, -2.25, 15>} 
#declare largeBackRock2 = object { largeBackRock rotate <-30, 160, 0> translate <5, -3, 16> } 

#declare bigRoundRockNearBack = isosurface 
{
        function{f_sphere(x,y,z, 0.4)-(fn_rock_2(x*1.25,y*1.4,z*1.3).grey*0.175)-(fn_rock_1(x*1,y*1,z*1).grey*0.08)}
//        function{f_sphere(x,y,z, rsize)-(fn_rock_2(x*0.1,y*0.1,z*0.1).grey*8)}
        threshold 0
        contained_by {box { <-0.765, -0.65, -0.625> <0.765, 0.65, 0.625>   } }
        accuracy isoAccuracy
        max_gradient 2.125  
        scale <3, 4, 3.5> 
        rotate <40, 30, -80>
        translate <2.4, 0.0, 5> 
}   

#declare rightRockInSand = isosurface 
{
        function{f_rounded_box(x,y,z, 0.04, 0.7, 0.4, 0.55)-(fn_rock_2(x*1,y*1,z*1).grey*0.3)-(fn_rock_1(x*1,y*1.5,z*1.25).grey*0.15)}
//        function{f_sphere(x,y,z, rsize)-(fn_rock_2(x*0.1,y*0.1,z*0.1).grey*8)}
        threshold 0
        contained_by {box { <-0.95, -0.85, -0.95> <0.95, 0.85, 0.95> } }
        accuracy isoAccuracy
        max_gradient 4.6  
        scale <2, 2, 4>
        rotate <0, 50, 0>
        rotate <-5, 0, 20>
        
        translate <7, -1, 2.5>   
#if(useTestTex)
texture { pigment { rgb 0.1 } }
#else
        material {
            texture { land_tex_t1 }
            interior { ior 1.4 }
        }
#end

}   

#if(showRocks)
union
{
        
        object {  largeBackRock1 }
        object {  largeBackRock2 }
        


        
       object { bigRoundRockNearBack }



        object { rightRockInSand }
#if(useTestTex)

        texture { pigment { rgb 0.08 } }
#else 
material {
texture { land_tex  }   
interior { ior 1.6 }
}
#end
} 

#end

#if(showSand)
        // ground rock.
        #declare groundRock = isosurface 
        {
                function{f_rounded_box(x,y,z, 0.02, 0.6, 0.15, 0.35)-(fn_rock_3(x,y*4,z*2).grey*0.15)-(fn_rock_4(x*15,y*10,z*15).grey*0.015)}//-(fn_rock_2(x*1.2,y*1.1,z*1.3).grey*0.075)-(fn_rock_1(x*1,y*1.25,z*1.15).grey*0.15)}
        //        function{f_sphere(x,y,z, rsize)-(fn_rock_2(x*0.1,y*0.1,z*0.1).grey*8)}
                threshold 0
                contained_by {box { <-0.8, -0.65, -0.6> <0.8, 0.65, 0.6>   } }
                accuracy 0.001
                max_gradient 1.5  
                scale <15, 10, 15>
             //   rotate <0, 60, 0>
             //   rotate <-50, 0, 10>   
                rotate <10, 0, 0>         
                translate <1.5, -2.5, 0> 
        }
        
        object { groundRock  
          
        #if(useTestTex)
        texture { pigment { rgb <0.5, 0.3, 0.1> } }
        #else 
        material {
 texture {
pigment { granite omega 0.8 lambda 2.2 turbulence 1 colour_map 
    { 
        [ 0 rgb <0.9, 0.8, 0.7>*1.1 ]  
        [ 0.2 rgb <0.9, 0.8, 0.7>*1.1 ]  
        [ 0.2 rgb <0.7, 0.5, 0.2>*1.1 ]  
        [ 0.4 rgb <0.7, 0.5, 0.2>*1.1 ]  
        [ 0.4 rgb <0.4, 0.2, 0.1>*1.5 ]  
        [ 0.6 rgb <0.4, 0.2, 0.1>*1.5 ]  
        [ 0.6 rgb <0.8, 0.7, 0.6>*1.1 ]  
        [ 0.8 rgb <0.8, 0.7, 0.6>*1.1 ]  
        [ 0.8 rgb <0.25, 0.225, 0.2>*1.5 ]  
        [ 1.0 rgb <0.25, 0.225, 0.2>*1.5 ]  

/*
        [ 0 rgb <0.9, 0.8, 0.7> ]  
        [ 0.2 rgb <0.9, 0.8, 0.7> ]  
        [ 0.2 rgb <0.7, 0.5, 0.2> ]  
        [ 0.4 rgb <0.7, 0.5, 0.2> ]  
        [ 0.4 rgb <0.4, 0.2, 0.1> ]  
        [ 0.6 rgb <0.4, 0.2, 0.1> ]  
        [ 0.6 rgb <0.8, 0.7, 0.6> ]  
        [ 0.8 rgb <0.8, 0.7, 0.6> ]  
        [ 0.8 rgb <0.25, 0.225, 0.2> ]  
        [ 1.0 rgb <0.25, 0.225, 0.2> ]  

*/

    }      
    scale 0.65
   }    
 //  normal { granite 0.5 omega 0.8 lambda 2.2 turbulence 1 scale 0.65/5 } 
   finish { diffuse albedo 0.5 specular albedo 0.1 roughness 0.075  }
  }
  interior { ior 1.55 }
  }    

  #end  
   
}     

// in the distance  
#declare groundRock2 = object { groundRock  
        scale <5, 1, 5>  
        rotate <-5, 0, 0>
        translate <0, -3, 15>  
        #if(useTestTex)
        texture { pigment { rgb <0.5, 0.3, 0.1> } }
        #else  
        material {
 texture {
pigment { granite omega 0.8 lambda 2.2 turbulence 1 colour_map 
    { 
        [ 0 rgb <0.9, 0.8, 0.7> ]  
        [ 0.2 rgb <0.9, 0.8, 0.7> ]  
        [ 0.2 rgb <0.7, 0.5, 0.2> ]  
        [ 0.4 rgb <0.7, 0.5, 0.2> ]  
        [ 0.4 rgb <0.4, 0.2, 0.1> ]  
        [ 0.6 rgb <0.4, 0.2, 0.1> ]  
        [ 0.6 rgb <0.8, 0.7, 0.6> ]  
        [ 0.8 rgb <0.8, 0.7, 0.6> ]  
        [ 0.8 rgb <0.25, 0.225, 0.2> ]  
        [ 1.0 rgb <0.25, 0.225, 0.2> ]  
    }      
    scale 0.65
   }    
 //  normal { granite 0.5 omega 0.8 lambda 2.2 turbulence 1 scale 0.65/5 } 
   finish { diffuse albedo 0.5 specular albedo 0.1 roughness 0.075  }
  }
  interior { ior 1.55 }
  }       
  #end      
}   

object { groundRock2 }


#if(showStones)

#macro mkStone()

#local s1 = stnr(0.25); 
#local s2 = stnr(0.2); 
#local s3 = stnr(0.3);     
#local s4 = stnr(0.12); 
#local s5 = stnr(0.15);  
#local s6 = stnr(0.1);  
#local s7 = stnr(1);     
#local s8 = stnr(0.125);     
#local s9 = stnr(0.01);     



   



isosurface {
  function { S(x,y*((1.25+(s1))-y/12),z)-f_wrinkles(x*(0.2+s2),y*(0.3+s3),z*(0.02+s4))*(0.03+s5)- 
               fn_scallop_ripples(x,y,z).gray*(0.001+s6)-f_wrinkles(x*(2+s7),y*(3+s7),z*(3+s7))*(0.005+s8)-f_crackle(x*15, y*15, z*15)*(0.01+s9) }
        accuracy isoAccuracy               
        max_gradient 2.75
        contained_by{sphere{0,2.2}}  
#if(useTestTex)
        texture { pigment {rgb 0.6} }
#else       
material {
texture
{
pigment {
        wrinkles          
        triangle_wave
        turbulence 0.55+tr(0.1)
        omega 0.8+tr(0.1)
        lambda 3+tr(1)
        colour_map
        {   
        #if(tr(1) > 0.75)
                [ 0.0 rgb <1, 0.99, 0.96>*(0.125+tr(0.5)) ]
                [ 0.2+tr(0.1) rgb <1, 0.96, 0.9>*(0.05+tr(0.4)) ]
                [ 0.4+tr(0.1) rgb <1, 0.965, 0.96>*(0.125+tr(0.5)) ]
                [ 0.7+tr(0.1) rgb <1, 0.99, 0.99>*(0.05+tr(0.4)) ]
                [ 1.0 rgb <1, 0.95, 0.95>*(0.125+tr(0.5)) ]
        #elseif(tr(1) > 0.4)
                [ 0.0 rgb <0.7, 0.69, 0.326>*(0.125+tr(0.5)) ]
                [ 0.2+tr(0.1) rgb <0.7, 0.6, 0.3>*(0.05+tr(0.4)) ]
                [ 0.4+tr(0.1) rgb <0.65, 0.6, 0.36>*(0.125+tr(0.5)) ]
                [ 0.7+tr(0.1) rgb <0.7, 0.64, 0.229>*(0.05+tr(0.4)) ]
                [ 1.0 rgb <0.7, 0.625, 0.3>*(0.125+tr(0.5)) ]
        #elseif(tr(1) > 0.7)
                [ 0.0 rgb <0.34, 0.02, 0.006>*(0.25+tr(0.2)) ]
                [ 0.2+tr(0.1) rgb <0.3, 0.02, 0.0>*(0.25+tr(0.2)) ]
                [ 0.4+tr(0.1) rgb <0.35, 0.02, 0.06>*(0.25+tr(0.2)) ]
                [ 0.7+tr(0.1) rgb <0.3, 0.01, 0.029>*(0.25+tr(0.2)) ]
                [ 1.0 rgb <0.36, 0.015, 0.0>*(0.25+tr(0.2)) ]
        #elseif(tr(1) > 0.5)
                [ 0.0 rgb <0.4, 0.29, 0.16>*(0.225+tr(0.8)) ]
                [ 0.2+tr(0.1) rgb <0.4, 0.3, 0.1>*(0.25+tr(0.6)) ]
                [ 0.4+tr(0.1) rgb <0.45, 0.3, 0.16>*(0.225+tr(0.8)) ]
                [ 0.7+tr(0.1) rgb <0.4, 0.3, 0.129>*(0.25+tr(0.6)) ]
                [ 1.0 rgb <0.44, 0.325, 0.1>*(0.125+tr(0.8)) ]
        #else
                [ 0.0 rgb <0.9, 0.9, 0.9>*(0.825+tr(0.1)) ]
                [ 0.2+tr(0.1) rgb <0.9, 0.9, 0.9>*(0.85+tr(0.1)) ]
                [ 0.4+tr(0.1) rgb <0.9, 0.9, 0.9>*(0.825+tr(0.1)) ]
                [ 0.7+tr(0.1) rgb <0.9, 0.9, 0.9>*(0.85+tr(0.1)) ]
                [ 1.0 rgb <0.9, 0.9, 0.9>*(0.725+tr(0.1)) ]
        #end                
        }  
        scale <0.75, 1.2, 0.5>*(0.5+tr(1))
        }                
}
texture
{
        pigment {
        ripples          
        scallop_wave
        turbulence 0.4+tr(0.3)
        omega 0.55+tr(0.1)
        lambda 4+tr(1)
        colour_map
        {
                [ 0.0 rgbt <1, 1, 1, 1> ]
                [ 0.9 rgbt <1, 1, 1, 1> ]
                [ 0.9 rgbt <0.2, 0.17, 0.12, 1> ]
                [ 0.92 rgbt <0.2, 0.17, 0.12, tr(0.6)> ]
                [ 0.94 rgbt <0.1, 0.072, 0.05, tr(0.4)> ]
                [ 0.99 rgbt <0.1, 0.072, 0.05, 1> ]
                [ 0.99 rgbt <1, 1, 1, 1> ]
                [ 1.0 rgbt <1, 1, 1, 1> ]
                
        }
        scale <0.25, 0.6, 0.15>*(1+tr(1))
        }
        finish { stoneFinishDamp }
}    

interior { ior 1.6 }  
}
#end                            

#local stoneH=0.3+stnr(0.7);
#local stoneS=0.001+stnr(0.025)+stnr(0.025)+stnr(0.025)+stnr(0.025);

#if(stnr(1) > 0.7)
translate <0, +stnr(0.5), 0>
#else
translate <0, 0.9+stnr(0.2), 0>
#end

scale <1, stoneH, 1>*stoneS
  
rotate <stnr(3), stnr(360), stnr(3)>
       
}


#end

/*
#declare stCount = 0;
#while(stCount < 55)
Drop_Object(groundRock, mkStone(), <-8+stnr(12), 10, -3+stnr(10)>, 1)
Drop_Object(groundRock, mkStone(), <-8+stnr(16), 10, -3+stnr(4)>, 1)
Drop_Object(groundRock2, mkStone(), <-16+stnr(32), 10, 8+stnr(10)>, 1)
#declare stCount=stCount+1;
#end
*/


#declare stCount = 0;
#while(stCount < 65)
Drop_Object(groundRock2, mkStone(), <-16+stnr(32), 10, 8+stnr(10)>, 1)
#declare stCount=stCount+1;
#end
/*
#declare stCount = 0;
#while(stCount < 25)                 
Drop_Object(groundRock, mkStone(), <-6+stnr(7), 10, -3+stnr(10)>, 1)
#declare stCount=stCount+1;
#end

#declare stCount = 0;
#while(stCount < 25)                 
Drop_Object(groundRock, mkStone(), <0+stnr(6), 10, -3+stnr(10)>, 1)
#declare stCount=stCount+1;
#end
*/                

// left side front
Drop_Object(groundRock, mkStone(), <-0.8, 10, -1.7>, 1)  
Drop_Object(groundRock, mkStone(), <-0.4, 10, -0.6>, 1)  

Drop_Object(groundRock, mkStone(), <0.2, 10, -1>, 1)
Drop_Object(groundRock, mkStone(), <0.4, 10, -1.3>, 1)

// front under water
Drop_Object(groundRock, mkStone(), <1.3, 10, -1.7>, 1)
Drop_Object(groundRock, mkStone(), <1.9, 10, -0.2>, 1)
Drop_Object(groundRock, mkStone(), <2.3, 10, -1.4>, 1)
Drop_Object(groundRock, mkStone(), <2.5, 10, -1.7>, 1)
Drop_Object(groundRock, mkStone(), <2.6, 10, -0.2>, 1)
Drop_Object(groundRock, mkStone(), <3.1, 10, -0.7>, 1)

// right side near starfish
Drop_Object(groundRock, mkStone(), <3.45, 10, 0.025>, 1) 
Drop_Object(groundRock, mkStone(), <4.25, 10, 0.25>, 1) 
Drop_Object(groundRock, mkStone(), <4.45, 10, -0.625>, 1)
Drop_Object(groundRock, mkStone(), <3.85, 10, -0.825>, 1)
Drop_Object(groundRock, mkStone(), <3.65, 10, -1.025>, 1)
Drop_Object(groundRock, mkStone(), <4.25, 10, -1.225>, 1)
Drop_Object(groundRock, mkStone(), <5.15, 10, -1.425>, 1)

// far right
Drop_Object(groundRock, mkStone(), <4.85, 10, -0.3>, 1)
Drop_Object(groundRock, mkStone(), <5.05, 10, -0.6>, 1)
Drop_Object(groundRock, mkStone(), <5.3, 10, -0.4>, 1)
Drop_Object(groundRock, mkStone(), <5.55, 10, -0.7>, 1)        

// middle under water in front of big rock
Drop_Object(groundRock, mkStone(), <0.5, 10, 0.7>, 1)
Drop_Object(groundRock, mkStone(), <1.5, 10, 0.9>, 1)
//Drop_Object(groundRock, mkStone(), <0.9, 10, 0.3>, 1)
Drop_Object(groundRock, mkStone(), <0.2, 10, 1.4>, 1)
//Drop_Object(groundRock, mkStone(), <1.5, 10, 1.7>, 1)
Drop_Object(groundRock, mkStone(), <0.8, 10, 2.2>, 1)
//Drop_Object(groundRock, mkStone(), <2.5, 10, 2.7>, 1)
Drop_Object(groundRock, mkStone(), <2.9, 10, 2.9>, 1)
//Drop_Object(groundRock, mkStone(), <1.1, 10, 3.1>, 1)
Drop_Object(groundRock, mkStone(), <0.2, 10, 3.0>, 1)
Drop_Object(groundRock, mkStone(), <3.6, 10, 3.2>, 1)
Drop_Object(groundRock, mkStone(), <3.2, 10, 3.5>, 1)
Drop_Object(groundRock, mkStone(), <4.2, 10, 3.9>, 1)

// top left 
#declare stCount = 0;
#while(stCount < 15)                 
Drop_Object(groundRock, mkStone(), <-4+stnr(6), 10, 1+stnr(4)>, 1)
#declare stCount=stCount+1;
#end




/*
#declare stCount = 0;
#while(stCount < 6000)
Drop_Object(groundRock, object { mkStone() scale 0.05+stnr(0.03)+stnr(0.03)+stnr(0.03)+stnr(0.03) }, <-8+stnr(12), 10, -3+stnr(10)>, 1)
Drop_Object(groundRock,  object { mkStone() scale 0.05+stnr(0.03)+stnr(0.03)+stnr(0.03)+stnr(0.03) }, <-8+stnr(20), 10, -3+stnr(4)>, 1)
#declare stCount=stCount+1;
#end
*/   


#declare stCount = 0;
#while(stCount < 5000)
Drop_Object(groundRock, object { mkStone() scale 0.03+stnr(0.025)+stnr(0.025)+stnr(0.025)+stnr(0.025) }, <-8+stnr(12), 10, -3+stnr(10)>, 1)
Drop_Object(groundRock,  object { mkStone() scale 0.03+stnr(0.025)+stnr(0.025)+stnr(0.025)+stnr(0.025) }, <-8+stnr(20), 10, -3+stnr(4)>, 1)
#declare stCount=stCount+1;
#end

#declare stCount = 0;
#while(stCount < 16000)
Drop_Object(groundRock, object { mkStone() scale 0.04+stnr(0.01)+stnr(0.01)+stnr(0.01)+stnr(0.01) }, <-8+stnr(12), 10, -3+stnr(10)>, 1)
Drop_Object(groundRock,  object { mkStone() scale 0.04+stnr(0.01)+stnr(0.01)+stnr(0.01)+stnr(0.01) }, <-8+stnr(20), 10, -3+stnr(4)>, 1)
#declare stCount=stCount+1;
#end


#end

#end 







// anemone
#if(showAnemone)

#macro mkAnemone()
blob{
  threshold 0.6 // threshold (0.0 < threshold <= Strength) surface falloff threshold #
  sphere{<0, 0.45, 0>, 1.2, 1 }

  sphere{<-0.1, 1.2+ar(0.1), 0>, 0.5, -1 }
  sphere{<0.1, 1.2+ar(0.1), 0>, 0.5, -1 }
  sphere{<0, 1.2+ar(0.1), -0.1>, 0.5, -1 }
  sphere{<0, 1.2+ar(0.1), 0.1>, 0.5, -1 }
  sphere{<0, 1.2+ar(0.1), 0>, 0.5, -1 }
  
  #local yRot=0;
  #while(yRot < 360)  
    #local xRot=-15;
    #while(xRot < 55)
        sphere{<0, 0, -0.9>, 0.2+ar(0.1), 1 rotate <xRot, yRot, 0> }    
        #local xRot=xRot+5;
    #end
        sphere{<0, 0, 0>, 0.2+ar(0.1), 1 scale <1, 0.75, 1.5> translate <0, 0, -0.9> rotate <-15, 0, 0> translate <0, 0, -0.05+ar(0.05)> rotate <0, yRot, 0>  }    
        sphere{<0, 0, 0>, 0.2+ar(0.1), 1 scale <1, 0.75, 2.5> translate <0, 0, -0.9> rotate <-17, 0, 0> translate <0, 0, -0.05+ar(0.05)> rotate <0, yRot, 0>  }    

    #local yRot=yRot+5;
  #end
  
#if(useTestTex)
 texture { pigment{ wrinkles triangle_wave colour_map { [ 0.0 color rgb <0.35+tr(0.05),0.0025,0.025> ] [ 0.9 rgb < 0.3+tr(0.05), 0.0025, 0.025> ]  } scale 0.1 } }
#else
 material {
 texture {
 pigment{ wrinkles omega 0.75 triangle_wave colour_map { 
    [ 0.0 rgbt <0.1+tr(0.1), 0.3+tr(0.2), 0.1+tr(0.1), 0.12> ] [ 0.3 rgbt <0.25+tr(0.05), 0.3+tr(0.2), 0.1+tr(0.1), 0.12> ]
    [ 0.5  rgbt <0.35+tr(0.05),0.0025,0.025, 0.12> ] [ 1.0 rgbt < 0.3+tr(0.05), 0.0025, 0.025, 0.12> ]
  } scale 0.1 }
           finish { diffuse albedo 0.5, 0.2 specular 0.1 roughness 0.05 brilliance 0.8  reflection { 0.01, 0.2 fresnel on } conserve_energy 
#if(useSubSurface)
      subsurface { translucency <3.0 1.59 1.79>*5 }  //0.9
#end
           }
         normal { granite 0.2 scale 0.0005 }
         }  
 interior { ior 1.4 } 
 }
#end           
 scale <1, 1, 1>*(0.0875+ar(0.025))   
 rotate <90, 0, 0>   
 translate <0, 0, -0.01>
 
   
 } 
#end           



#macro mkTentacle(rad, spos, epos, tSpline, yRot, xRot, zPos, yPos)
        #local lspos = spos;
        #local nextBlob=lspos;
        #local srad=rad;
                
                

                #while (lspos < epos)      
                   
              
                   #local Direction = (tSpline(lspos+0.001) -tSpline(lspos-0.001));   


                   sphere { 0, srad, Strength   
                //   transform {Reorient_Trans(x,Direction)}   
                   translate tSpline(lspos)
                   rotate <xRot, 0, 0>                            
                   translate <0, yPos, zPos>
                   rotate <0, yRot, 0>  
                   
                   }  
                   
                   #local srad=srad*0.99;
                   
                   #local lspos = getSplinePos(tSpline, lspos, srad*0.1, 0.001);                    

                #end                 
#end



#macro mkAnemoneOpen()  
#local tPos=0;
#local tDist=10;  

#declare tentacle_spline1 = spline {
         natural_spline
         0.00, <0, 0.0, 0>
         0.3, <ar(0.05), 0.5, -0.15> 
         0.8, <0.0, 0.75, -(0.35+ar(0.2))> 
         1.0, <-ar(0.05), 0.9, -(0.4+ar(0.15))>   
       };

#declare tentacle_spline2 = spline {
         natural_spline
         0.00, <0, 0.0, 0>
         0.3, <ar(0.05), 0.3, -0.25> 
         0.8, <0.0, 0.6, -(0.5+ar(0.1))> 
         1.0, <-ar(0.05), 0.75, -(0.6+ar(0.1))>   
       };

#declare tentacle_spline3 = spline {
         natural_spline
         0.00, <0, 0.0, 0>
         0.3, <ar(0.05), 0.2, -0.35> 
         0.8, <0.0, 0.4, -(0.7+ar(0.1))> 
         1.0, <-ar(0.05), 0.395, -(0.9+ar(0.1))>   
       };

#declare tentacle_spline4 = spline {
         natural_spline
         0.00, <0, 0.0, 0>
         0.3, <ar(0.05), 0.1, -0.4> 
         0.8, <0.0, 0.05, -(0.7+ar(0.1))> 
         1.0, <-ar(0.05), 0.1, -(1+ar(0.1))>   
       };


        
blob{
  threshold 0.6 // threshold (0.0 < threshold <= Strength) surface falloff threshold #
  sphere{<0, 0, 0>, 1.2, 1 scale <2.75, 0.5, 2.75> translate <0, 0.7, 0> }
  sphere{<0, 0, 0>, 1.2, 1 scale <.5, 0.75, .5> translate <0, 0.9, 0> }
  sphere{<0, 0, 0>, 1.2, -1 scale <.25, 0.75, .25> translate <0, 1.52, 0> }
  sphere{<0, 0, 0>, 1.2, -1 scale <.04, 0.75, .5> translate <0, 1.7, 0> }
  sphere{<0, 0, 0>, 1.2, -1 scale <.05, 0.75, .5> translate <0, 1.75, 0> rotate <0, 70, 0> }
  sphere{<0, 0, 0>, 1.2, -1 scale <.05, 0.75, .5> translate <0, 1.7, 0> rotate <0, 140, 0> }
  sphere{<0, 0, 0>, 1.2, -1 scale <.04, 0.75, .5> translate <0, 1.735, 0> rotate <0, 210, 0> }
  sphere{<0, 0, 0>, 1.2, -1 scale <.05, 0.75, .5> translate <0, 1.72, 0> rotate <0, 290, 0> }

//  sphere{<0, 0, 0>, 1, -0.6 scale <0.8, 0.8, 0.1> translate <0, 1, 0> }

  #local yRot=0;
  #while(yRot <= 360)  
    #local xRot=-15;
    #while(xRot < 25)
        sphere{<0, 0, -0.9>, 0.2+ar(0.1), 1 rotate <xRot, yRot, 0> }    
        #local xRot=xRot+5;
    #end

    // tentacles    
    #if(yRot > tPos+tDist)
        mkTentacle(0.15, 0.01, 1, tentacle_spline1, yRot, -(ar(20)), -(0.9+ar(0.05)), 0.9+ar(0.05))
        mkTentacle(0.15, 0.01, 1, tentacle_spline2, yRot+4+ar(4), -(ar(20)), -(1.05+ar(0.025)), 0.875+ar(0.05))
        mkTentacle(0.15, 0.01, 1, tentacle_spline3, yRot+ar(2), -(ar(15)), -(1.3+ar(0.025)), 0.85+ar(0.05))
        mkTentacle(0.15, 0.01, 1, tentacle_spline4, yRot+4+ar(4), -(20+ar(15)), -(1.6+ar(0.025)), 0.725+ar(0.025))
    #local tPos=yRot;
    #end


        sphere{<0, 0, 0>, 0.2+ar(0.1), 1 scale <1, 0.75, 1.5> translate <0, 0, -0.9> rotate <-15, 0, 0> translate <0, 0, -0.05+ar(0.05)> rotate <0, yRot, 0>  }    
        sphere{<0, 0, 0>, 0.2+ar(0.1), 1 scale <1, 0.75, 2.5> translate <0, 0, -0.9> rotate <-17, 0, 0> translate <0, 0, -0.05+ar(0.05)> rotate <0, yRot, 0>  }    

    #local yRot=yRot+5;
  #end
  
#if(useTestTex)
 texture { pigment{ wrinkles triangle_wave colour_map { [ 0.0 color rgb <0.35+tr(0.05),0.0025,0.025> ] [ 0.9 rgb < 0.3+tr(0.05), 0.0025, 0.025> ]  } scale 0.1 } }
#else
 material {
 texture {
 pigment{ wrinkles omega 0.75 triangle_wave colour_map { 
    [ 0.0 rgbt <0.1+tr(0.1), 0.3+tr(0.2), 0.1+tr(0.1), 0.12> ] [ 0.3 rgbt <0.25+tr(0.05), 0.3+tr(0.2), 0.1+tr(0.1), 0.12> ]
    [ 0.5  rgbt <0.35+tr(0.05),0.0025,0.025, 0.12> ] [ 1.0 rgbt < 0.3+tr(0.05), 0.0025, 0.025, 0.12> ]
  } scale 0.1 }
           finish { diffuse albedo 0.5, 0.2 specular 0.1 roughness 0.05 brilliance 0.8  reflection { 0.01, 0.2 fresnel on } conserve_energy 
#if(useSubSurface)
      subsurface { translucency <3.0 1.59 1.79>*5 }  //0.9
#end
           }
         normal { granite 0.2 scale 0.0005 }
         }  
 interior { ior 1.4 } 
 }
#end           
 scale <1, 1.5+ar(0.5), 1>*(0.075+ar(0.025))   
 rotate <90, 0, 0>   
 translate <0, 0, -0.01>
 
   
 } 
#end

//object { mkAnemone() rotate <-90, 0, 0> translate <2, 3, -3.75> }

//object { mkAnemone() rotate <0, 0, -2> translate <2.55, 0.12, -1.65> }
//object { mkAnemone() rotate <30, 0, -10> translate <2.7, 0.035, -1.375> }
//object { mkAnemone() rotate <70, 0, 0> translate <3, 0, -1.475> }          



#declare anPos = -8;
#while(anPos < 4) 
Place_Object(largeBackRock1, object{ mkAnemone() rotate <0, 0, 0> }, <anPos, -0.3+ar(0.4), 0>, 1)
Place_Object(largeBackRock2, object{ mkAnemone() rotate <0, 0, 0> }, <anPos+8, -0.3+ar(0.4), 0>, 1)
#declare anPos=anPos+1.5+ar(2);
#end

#declare anPos = -8;
#while(anPos < 4) 
Place_Object(largeBackRock1, object{ mkAnemoneOpen() rotate <0, 0, 0> }, <anPos, -1+ar(0.5), 0>, 1)
Place_Object(largeBackRock2, object{ mkAnemoneOpen() rotate <0, 0, 0> }, <anPos+8, -1+ar(0.5), 0>, 1)
#declare anPos=anPos+2.25+ar(2.5);
#end


//Place_Object(largeBackRock1, mkAnemone(), <anemonePos, -0.3+ar(0.2), 0>, 1)
//Place_Object(largeBackRock2, mkAnemone(), <anemonePos+8, -0.3+ar(0.2), 0>, 1)

Place_Object(bigRoundRockNearBack, mkAnemone(), <2, -0.2, 0>, -2)
Place_Object(bigRoundRockNearBack, mkAnemone(), <2.2, -0.15, 0>, -2)
Place_Object(bigRoundRockNearBack, mkAnemone(), <3.55, -0.125, 0>, -2)

Place_Object(bigRoundRockNearBack, mkAnemoneOpen(), <3.25, -0.265, 0>, -2)
Place_Object(bigRoundRockNearBack, mkAnemoneOpen(), <1, -0.375, 0>, -2)

object { mkAnemoneOpen() scale 1 rotate <-90, 0, 30> translate <4.0, -0.51, 1.8> }



#end

#if(showLimpets)

#macro mkLimpetPart(rad, spos, epos, tSpline, yRot, xRot, zPos, yPos, bStrength)
        #local lspos = spos;
        #local nextBlob=lspos;
        #local srad=rad;
                
                

                #while (lspos < epos)      
                   
              
                   #local Direction = (tSpline(lspos+0.001) -tSpline(lspos-0.001));   


                   sphere { 0, (srad*0.8)+lr(srad/2), bStrength scale <0.5+lr(0.2), 1, 1>  
                //   transform {Reorient_Trans(x,Direction)}   
                   translate tSpline(lspos)
                   rotate <xRot, 0, 0>                            
                   translate <0, yPos, zPos>
                   rotate <0, yRot, 0>  
                   
                   }  
                   
                   #local srad=srad*0.999;
                   
                   #local lspos = getSplinePos(tSpline, lspos, srad*0.125, 0.001);                    

                #end   
#end


#macro mkLimpet()

blob{
  threshold 0.6 // threshold (0.0 < threshold <= Strength) surface falloff threshold #
  #local zOff=0;
  #local zOffScale=0.025+lr(0.35);
  
  #local yOff=0.475+lr(0.175);

  #local yRot=0;
  #while(yRot < 360)
  
#local zOff=sin(radians(yRot/2))*(zOffScale+lr(0.001));

#local limpetSpline = spline {
         natural_spline
         0.00, <0, 0.0, -(1-zOff)>
         0.45+lr(0.1), <0.0, yOff, -(0.5-(zOff/2))> 
         1.0, <0, 1, 0.0>   
       };   



  
        mkLimpetPart(0.1, 0.001, 1, limpetSpline, yRot, 0, 0, 0, 1)
        mkLimpetPart(0.1, 0.001, 1, limpetSpline, yRot+5, 0, 0, -0.025, 1)
        mkLimpetPart(0.1, 0.001, 1, limpetSpline, yRot+5, 0, 0, 0.025, -1)
        
  
    
/*
    #local xRot=0;
    #while(xRot < 80)
        sphere{<0, 1, 0>, 0.1+lr(0.01), 1 scale <0.5, 1, 1> rotate <xRot, yRot, 0>  }    
        sphere{<0, 0.9, 0>, 0.2+lr(0.01), 1 rotate <xRot, yRot+5, 0>}    
        sphere{<0, 0.85, 0>, 0.2+lr(0.01), -1 rotate <xRot, yRot+5, 0>   }    
        sphere{<0, 1.05, 0>, 0.1+lr(0.01), -1 scale <0.5, 1, 1>  rotate <xRot, yRot+4, 0> }    
        #local xRot=xRot+5+lr(4);
    #end
*/

/*
    #local xRot=0;
    #while(xRot < 50)
        sphere{<0, 0.4, 0>, 0.05+lr(0.01), 1 rotate <xRot, yRot, 0> translate <0, 0.7, 0> scale <1, 1.25, 1>}    
        #local xRot=xRot+3;
    #end
*/

     #local yRot=yRot+9+lr(2);
    
  #end

                scale 0.35+lr(0.65)
                scale <0.2, 0.125+lr(0.08), 0.2>              

 #local lpTexOff=0.4+tr(0.2);   
 
 #if(useTestTex)
 texture { pigment{ agate agate_turb 0.4  omega 0.7 lambda 1.5
 colour_map 
 { 
 [ 0.0 rgb <0.9, 0.8, 0.75> ]  
 [ 1.0 rgb <0.8, 0.75, 0.65> ]  
 
 } 
                translate <tr(1), tr(1), tr(1)>
 scale 0.1+tr(0.2)
 } 
 }
 #else 
 
 material {
 texture { pigment{ agate agate_turb 0.4  omega 0.7 lambda 1.5
 colour_map 
 { 
 [ 0.0 rgb <0.05, 0.1, 0.15+tr(0.15)> ]  
 [ 1.0 rgb <0.001, 0.05, 0.15+tr(0.1)> ]  
 
 } 
                translate <tr(1), tr(1), tr(1)>
 scale 0.1+tr(0.2)
 } 
 }
 texture { pigment{ granite turbulence 0.4 omega 0.7
 colour_map 
 { 
 [ 0.0 rgbt <0.9, 0.85, 0.77, 0.9> ]  
 [ lpTexOff*1.5 rgbt <0.8, 0.77, 0.65, 0.05> ]  
 
 } 
                translate <tr(1), tr(1), tr(1)>
 scale 0.1+gr(0.3) }
  }    
  texture
{   
        pigment 
        {
                crackle            
                turbulence 0.35+tr(0.2) form <1, 0, 0>  
                omega 0.7+tr(0.1) lambda 3+tr(1)
                scale 0.2+tr(0.2)     
                color_map
                {
                        [ 0.0 rgbt <0.06, 0.025, 0.002, 0.01> ] 
                        [ lpTexOff rgbt <0.11, 0.05, 0.001, 0.1> ] 
                        [ lpTexOff+0.1 rgbt <0.125, 0.055, 0.002, 1> ] 
                        [ lpTexOff+0.1 rgbt 1 ]
                        [ 1.0 rgbt 1 ]
                }
        } 
                translate <tr(1), tr(1), tr(1)>
        scale 1+tr(2) rotate <tr(90), tr(90), tr(90)>
}
texture
{   
        pigment 
        {
                crackle            
                turbulence 0.35+tr(0.2) form <1, 0, 0>  
                omega 0.7+tr(0.1) lambda 3+tr(1)
                scale 0.2+tr(0.2)     
                color_map
                {
                        [ 0.0 rgbt <0.52, 0.3, 0.04, 0.01> ] 
                        [ 0.2 rgbt <0.62, 0.45, 0.02, 0.1> ] 
                        [ 0.3 rgbt <0.62, 0.45, 0.02, 1> ] 
                        [ 0.3 rgbt 1 ]
                        [ 1.0 rgbt 1 ]
                }   
                translate <tr(1), tr(1), tr(1)>
                scale 0.5+tr(0.5)
        }

  finish { specular 0.1 roughness 0.5 brilliance 1.3 diffuse albedo 0.5 phong 0.3 phong_size 5 reflection { 0.009, 0.025 fresnel on } conserve_energy }
  normal { agate 0.4+tr(0.3) scale 0.15+tr(0.15) }

}
interior { ior 1.6 }
}       
 #end
 rotate <0, lr(360), 0> 
 } 
#end 






Drop_Object(rightRockInSand, mkLimpet(), <5.2, 6, 2.884>, 1)


Drop_Object(rightRockInSand, mkLimpet(), <4.7, 5, 1.6>, 1)
Drop_Object(rightRockInSand, mkLimpet(), <4.8, 5, 1.35>, 1)
Drop_Object(rightRockInSand, mkLimpet(), <4.8, 5, 1.0>, 1)

Drop_Object(rightRockInSand, mkLimpet(), <5.9, 5, 0.8>, 1)

// round rock limpets

Drop_Object(bigRoundRockNearBack, mkLimpet(), <3.75, 6, 4.1>, 1)
Drop_Object(bigRoundRockNearBack, mkLimpet(), <3.45, 6, 4.3>, 1)
Drop_Object(bigRoundRockNearBack, mkLimpet(), <3.25, 6, 3.9>, 1)

Place_Object(bigRoundRockNearBack, object{ mkLimpet() rotate <90, 0, 0> }, <1.4, 0.8, 0>, 1)
Place_Object(bigRoundRockNearBack, object{ mkLimpet() rotate <90, 0, 0> }, <1.6, 1.1, 0>, 1)
Place_Object(bigRoundRockNearBack, object{ mkLimpet() rotate <90, 0, 0> }, <1.7, 0.6, 0>, 1)
Place_Object(bigRoundRockNearBack, object{ mkLimpet() rotate <90, 0, 0> }, <1.9, 0.8, 0>, 1)
Place_Object(bigRoundRockNearBack, object{ mkLimpet() rotate <90, 0, 0> }, <2.4, 0.9, 0>, 1)
Place_Object(bigRoundRockNearBack, object{ mkLimpet() rotate <90, 0, 0> }, <2.8, 0.75, 0>, 1)

#declare limpetPos = -8;
#while(limpetPos < 4) 
Place_Object(largeBackRock1, object{ mkLimpet() rotate <90, 0, 0> }, <limpetPos, -1.65+lr(2), 0>, 1)
Place_Object(largeBackRock2, object{ mkLimpet() rotate <90, 0, 0> }, <limpetPos+8, -1.65+lr(2), 0>, 1)
#declare limpetPos=limpetPos+0.175+lr(0.4);
#end

#end // end of showLimpets  



// barnacles..
                            
                            
#macro mkBarnaclePart(rad, spos, epos, tSpline, yRot, xRot, zPos, yPos, bStrength)
        #local lspos = spos;
        #local nextBlob=lspos;
        #local srad=rad;
                
                

                #while (lspos < epos)      
                   
              
                   #local Direction = (tSpline(lspos+0.001) -tSpline(lspos-0.001));   


                   sphere { 0, (srad*0.8)+br(srad/2), bStrength scale <0.8+br(0.2), 0.5, 0.3>  
                //   transform {Reorient_Trans(x,Direction)}   
                   translate tSpline(lspos)
                   rotate <xRot, 0, 0>                            
                   translate <0, yPos, zPos>
                   rotate <0, yRot, 0>  
                   
                   }  
                   
                   #local srad=srad*0.999;
                   
                   #local lspos = getSplinePos(tSpline, lspos, srad*0.15, 0.01);                    

                #end   
#end


#macro mkBarnacle()
#local alive=br(1);

union {
blob{
  threshold 0.6 // threshold (0.0 < threshold <= Strength) surface falloff threshold #
  #local zOff=0;
  #local zOffScale=0.025+br(0.1);
  
  #local yOff=0.55+br(0.1);

  #local yRot=0;
  #while(yRot < 360)
  
#local zOff=sin(radians(yRot/2))*(zOffScale+br(0.001));

#local barnacleSpline = spline {
         natural_spline
         0.00, <0, 0.0, -(1-zOff)>
         0.45+br(0.1), <0.0, yOff, -(0.55-(zOff/2))> 
         1.0, <0, 1, 0.0>   
       };   



  
        mkBarnaclePart(0.2, 0.001, 0.5, barnacleSpline, yRot, 0, 0, 0, 1)
        mkBarnaclePart(0.2, 0.001, 0.5, barnacleSpline, yRot+7.5, 0, 0, -0.025, 1)
        mkBarnaclePart(0.2, 0.001, 0.5, barnacleSpline, yRot+7.5, 0, 0, 0.025, -1)
        
  
    

     #local yRot=yRot+19+br(2);
    
  #end   
  // inner part
 // sphere { <0, 0, 0> 0.8, 1 scale <1, 1, 0.5> rotate <15, 0, 0> translate <0, 0.6, -0.2> }
/*
  cylinder { <-(zOffScale*3), (yOff*2)+(zOffScale*5), 0>, <(zOffScale*3), (yOff*2)+(zOffScale*5), 0> zOffScale*2, -1 scale <1, 1, 0.5> }

  sphere { <0, yOff, 0> zOffScale*15, 1 scale <1, 1, 0.5> translate <0, 0, zOffScale*3.25> }
  
*/

}
#if(alive > 0.5)
intersection { 
union {
  union {
    intersection {
          sphere { <0, 0, 0> 1  }
          box { <-1.1, -1.1, 0> <1.1, 1.1, 1.1> }
    }
    torus { 0.9, 0.1 rotate <90, 0, 0> }
    cylinder { <0, 0, -0.1> <0, 0, 0.1> 0.9 } 
    scale <0.8, 0.7, 0.7> 
    rotate <10, 0, 0>  
  }

  union {
    intersection {
          sphere { <0, 0, 0> 1  }
          box { <-1.1, -1.1, -1.1> <1.1, 1.1, 0> }
    }
    torus { 0.9, 0.1 rotate <90, 0, 0> }
    cylinder { <0, 0, -0.1> <0, 0, 0.1> 0.9 } 
    scale <0.8, 0.7, 0.7> 
    rotate <-10, 0, 0>  
  }
  }
    box { <-1.1, 0, -1.1> <1.1, 1.1, 1.1> }
}
#end
                scale 0.35+br(0.65)
                scale <0.2, 0.2+br(0.1), 0.2>              

 #local lpTexOff=0.4+tr(0.2);   
 
 #if(useTestTex)
 texture { pigment{ agate agate_turb 0.4  omega 0.7 lambda 1.5
 colour_map 
 { 
 [ 0.0 rgb <0.7, 0.6, 0.55> ]  
 [ 0.5 rgb 1 ]  
 [ 1.0 rgb <0.6, 0.55, 0.35> ]  
 
 } 
                translate <tr(1), tr(1), tr(1)>
 scale 0.1+tr(0.2)
 } 
 }
 #else 
#if(alive > 0.5) 
 material {
 texture { pigment{ agate agate_turb 0.4  omega 0.7 lambda 1.5
 colour_map 
 { 
 [ 0.0 rgb <0.9, 0.875, 0.85> ]  
 [ 0.5 rgb 1 ]  
 [ 1.0 rgb <0.8, 0.775, 0.425> ]  
 
 
 } 
                translate <tr(1), tr(1), tr(1)>
 scale 0.1+tr(0.2)
 } 
 }
 texture { pigment{ granite turbulence 0.4 omega 0.7
 colour_map 
 { 
 [ 0.0 rgbt <0.9, 0.875, 0.82, 0.9> ]  
 [ lpTexOff*1.5 rgbt <0.5, 0.4, 0.3, 0.05> ]  
 
 } 
                translate <tr(1), tr(1), tr(1)>
 scale 0.1+gr(0.3) } 
  finish { specular 0.15 roughness 0.05 brilliance 1.8 diffuse albedo 0.55 phong 0.2 phong_size 55  conserve_energy }
  normal { agate 0.4+tr(0.3) scale 0.15+tr(0.15) }
 
  }    
interior { ior 1.6 }
}
#else // dead tex

 material {
 texture { pigment{ agate agate_turb 0.4  omega 0.7 lambda 1.5
 colour_map 
 { 
 [ 0.0 rgb <0.1, 0.05, 0.01>*(0.5+tr(0.5)) ]  
 [ 0.5 rgb 0.5 ]  
 [ 1.0 rgb <0.05, 0.035, 0.005>*(0.5+tr(0.5)) ]  
 
 } 
 translate <tr(1), tr(1), tr(1)>
 scale 0.1+tr(0.2)
 } 
 }
 texture { pigment{ granite turbulence 0.4 omega 0.7
 colour_map 
 { 
 [ 0.0 rgbt <0.9, 0.85, 0.77, 0.9> ]  
 [ lpTexOff*1.5 rgbt <0.8, 0.77, 0.65, 0.05> ]  
 
 } 
  translate <tr(1), tr(1), tr(1)>
 scale 0.1+gr(0.3) }
  }    
  texture
{   
        pigment 
        {
                crackle            
                turbulence 0.35+tr(0.2) form <1, 0, 0>  
                omega 0.7+tr(0.1) lambda 3+tr(1)
                scale 0.2+tr(0.2)     
                color_map
                {
                        [ 0.0 rgbt <0.06, 0.025, 0.002, 0.01> ] 
                        [ lpTexOff rgbt <0.11, 0.05, 0.001, 0.1> ] 
                        [ lpTexOff+0.1 rgbt <0.125, 0.055, 0.002, 1> ] 
                        [ lpTexOff+0.1 rgbt 1 ]
                        [ 1.0 rgbt 1 ]
                }
        } 
                translate <tr(1), tr(1), tr(1)>
        scale 1+tr(2) rotate <tr(90), tr(90), tr(90)>
}
texture
{   
        pigment 
        {
                crackle            
                turbulence 0.35+tr(0.2) form <1, 0, 0>  
                omega 0.7+tr(0.1) lambda 3+tr(1)
                scale 0.2+tr(0.2)     
                color_map
                {
                        [ 0.0 rgbt <0.42, 0.3, 0.14, 0.01> ] 
                        [ 0.2 rgbt <0.52, 0.45, 0.11, 0.1> ] 
                        [ 0.3 rgbt <0.52, 0.45, 0.21, 1> ] 
                        [ 0.3 rgbt 1 ]
                        [ 1.0 rgbt 1 ]
                }   
                translate <tr(1), tr(1), tr(1)>
                scale 0.5+tr(0.5)
        }

  finish { specular 0.15 roughness 0.05 brilliance 1.8 diffuse albedo 0.5 phong 0.2 phong_size 75  conserve_energy }
  normal { agate 0.8+tr(0.3) scale 0.15+tr(0.15) }

}
interior { ior 1.6 }
}  

#end // end of if alive
       
 #end
 rotate <0, br(360), 0> 
 } 
#end                             

#declare  F_BumpsA= function { pigment{bumps turbulence 0.295 omega 0.8 lambda 4 scale 0.255} }
#if(showBarnacles)      


// barnacles on right rock
#declare bRand = 0;
#declare barn1 = object { mkBarnacle()  }
#declare bHit=1;

#while(bRand < 1500) //5000

#if(mod(bRand,50) = 0)
#if(bHit=1)
#declare barn1 = object { mkBarnacle()   }
#end
#end

#declare X = br(1);
#declare Z = br(1);

//#if (br(1) < f_distribution(X,0,Z))
#if(F_BumpsA(X, 0.5, Z).red > 0.4+br(0.4))
//#if(br(1)< F_Bumps(X,0,Z).x)
Drop_Object(rightRockInSand, object { barn1 scale 0.125+br(0.175) rotate <0, br(360), 0> }, <3+(X*6), 6, -1+(Z*5)>, 1)
#declare bRand=bRand+1;  
#warning concat("Barnacle Count=",str(bRand, 5, 5))    
#warning concat(" X=",str(X, 5, 5))                                                              
#warning concat(" Z=",str(Z, 5, 5))                                                              
                                                          
#declare bHit=1;
#else
#declare bHit=0;
#end

#end 

// barnacles on middle round rock
#declare bRand = 0;
#declare barn1 = object { mkBarnacle()  }
#declare bHit=1;

#while(bRand < 2500) //5000

#if(mod(bRand,50) = 0)
#if(bHit=1)
#declare barn1 = object { mkBarnacle()   }
#end
#end

#declare X = br(1);
#declare Z = br(1);




//#if (br(1) < f_distribution(X,0,Z))
#if(F_BumpsA(X, 0.5, Z).red > 0.4+br(0.1))
//#if(br(1)< F_Bumps(X,0,Z).x)
//Drop_Object(bigRoundRockNearBack, object { barn1 scale 0.125+br(0.175) rotate <0, br(360), 0> }, <0.75+(X*4), 6, 3.5+(Z*4)>, 1)

Place_Object(bigRoundRockNearBack, object{ barn1 scale 0.125+br(0.175) rotate <0, br(360), 0>  rotate <90, 0, 0> }, <0.75+(X*4),(Z*3), 0>, 1)


#declare bRand=bRand+1;  
#warning concat("Barnacle Count=",str(bRand, 5, 5))    
#warning concat(" X=",str(X, 5, 5))                                                              
#warning concat(" Z=",str(Z, 5, 5))                                                              
                                                          
#declare bHit=1;
#else
#declare bHit=0;
#end

#end           


// barnacles on big left rock at back
#declare bRand = 0;
#declare barn1 = object { mkBarnacle()  }
#declare bHit=1;

#while(bRand < 3500) //5000

#if(mod(bRand,50) = 0)
#if(bHit=1)
#declare barn1 = object { mkBarnacle()   }
#end
#end

#declare X = br(1);
#declare Z = br(1);


#if(F_BumpsA(X, 0.5, Z).red > 0.4+br(0.4))
//#if(br(1)< F_Bumps(X,0,Z).x)  
Drop_Object(largeBackRock1, object { barn1 scale 0.125+br(0.175) rotate <0, br(360), 0> }, <-10+(X*12), 10, 9+(Z*8)>, 1)
#declare bRand=bRand+1;  
#warning concat("Barnacle Count=",str(bRand, 5, 5))    
#warning concat(" X=",str(X, 5, 5))                                                              
#warning concat(" Z=",str(Z, 5, 5))                                                              
                                                          
#declare bHit=1;
#else
#declare bHit=0;
#end

#end           

// barnacles on big right rock at back
#declare bRand = 0;
#declare barn1 = object { mkBarnacle()  }
#declare bHit=1;

#while(bRand < 3500) //5000

#if(mod(bRand,50) = 0)
#if(bHit=1)
#declare barn1 = object { mkBarnacle()   }
#end
#end

#declare X = br(1);
#declare Z = br(1);


#if(F_BumpsA(X, 0.5, Z).red > 0.4+br(0.4))
//#if(br(1)< F_Bumps(X,0,Z).x)
Drop_Object(largeBackRock2, object { barn1 scale 0.125+br(0.175) rotate <0, br(360), 0> }, <-3+(X*12), 10, 10+(Z*8)>, 1)
#declare bRand=bRand+1;  
#warning concat("Barnacle Count=",str(bRand, 5, 5))    
#warning concat(" X=",str(X, 5, 5))                                                              
#warning concat(" Z=",str(Z, 5, 5))                                                              
                                                          
#declare bHit=1;
#else
#declare bHit=0;
#end

#end           

#end // end of show barnacles


/*
      
#declare bRand = 0;
#declare barn1 = object { mkBarnacle()  }

#while(bRand < 1000)

#if(mod(bRand,100) = 0)
#declare barn1 = object { mkBarnacle()  }
#end
      
object { barn1 scale 0.2+br(0.8) translate <1+br(8), -2+br(0.1), 2+br(10)> } 

#declare bRand=bRand+1;
#end
*/
/*
object { mkBarnacle() scale 1 translate <1, 1, 2> } 
object { mkBarnacle() scale 1 translate <2, 1, 2> } 
object { mkBarnacle() scale 1 translate <3, 1, 2> } 
object { mkBarnacle() scale 1 translate <4, 1, 2> } 
object { mkBarnacle() scale 1 translate <5, 1, 2> } 

object { mkBarnacle() scale 1 translate <0, 2, 2> } 
object { mkBarnacle() scale 1 translate <1, 2, 2> } 
object { mkBarnacle() scale 1 translate <2, 2, 2> } 
object { mkBarnacle() scale 1 translate <3, 2, 2> } 
object { mkBarnacle() scale 1 translate <4, 2, 2> } 
object { mkBarnacle() scale 1 translate <5, 2, 2> } 
*/
 
 




/********************* Green moss like Seaweed  ***************************/

#if(showSeaweed)

#if(useTestTex)
#declare mossMatDark =   material {    
  texture{ pigment{ rgb <0.2, 0.4, 0.1> }
         } // end of texture          
          interior { ior 2.6 }
         }
#declare mossMat =   material {    
  texture{ pigment{ rgb <0.2, 0.4, 0.1> }
         } // end of texture          
          interior { ior 2.6 }
         }
#else
#declare mossMatDark =   material {    
  texture{ pigment{ wrinkles triangle_wave colour_map { [0.0 rgb <0.6, 0.52, 0.01>*(0.15+tr(0.2)) ] [1.0 rgb <0.32, 0.35, 0.1>*(0.15+tr(0.2))] } scale 0.15 }
           finish { specular  0.1 roughness 0.05 
           diffuse albedo 0.3 0.2 brilliance 0.85    }  
           normal { average normal_map { [ 1 wrinkles 0.5 scale 0.001 ] [ 1 bumps 0.5 scale 0.02 ]  } }//wrinkles 1 scale 0.001 } // bumps 1 scale 0.02  }
            
         }   
  texture{ pigment{ granite triangle_wave colour_map { [0.0 rgbt <0.06, 0.035, 0.005, 0.01> ] [0.2+tr(0.1) rgbt <0.09, 0.05, 0.008, 0.1> ] [0.6+tr(0.2) rgbt <0.09, 0.05, 0.003, 1> ] } scale 0.5 }
           finish { specular  0.1 roughness 0.025
           diffuse albedo 0.3 0.2 brilliance 1.85 reflection { 0.007, 0.05 fresnel on } conserve_energy } 
           normal { granite 0.1 scale 0.001 }
            
         }   
         interior { ior 2.6 }
         }  
         
#declare mossMat =   material {    
  texture{ pigment{ wrinkles triangle_wave colour_map { [0.0 rgb <0.6, 0.52, 0.01>*(0.25+tr(0.2)) ] [1.0 rgb <0.32, 0.35, 0.1>*(0.25+tr(0.2))] } scale 0.15 }
           finish { specular  0.2 roughness 0.05 phong 0.05 phong_size 20
           diffuse albedo 0.5 0.4 brilliance 1.5   }  
           normal { average normal_map { [ 1 wrinkles 0.5 scale 0.001 ] [ 1 bumps 0.5 scale 0.02 ]  } }//wrinkles 1 scale 0.001 } // bumps 1 scale 0.02  }
            
         }   
  texture{ pigment{ granite triangle_wave colour_map { [0.0 rgbt <0.06, 0.035, 0.005, 0.01> ] [0.2+tr(0.1) rgbt <0.09, 0.05, 0.008, 0.1> ] [0.6+tr(0.2) rgbt <0.09, 0.05, 0.003, 1> ] } scale 0.5 }
           finish { specular  0.01 roughness 0.25
           diffuse albedo 0.5 0.4 brilliance 0.85 reflection { 0.01, 0.35 fresnel on } conserve_energy  } 
           normal { granite 0.1 scale 0.001 }
            
         }   
         interior { ior 2.6 }
         }
#end


#declare Fn_moss_1 =
 function(x, y, z)
  {1+f_snoise3d(x*1.70,y*1.70,z*1.70)*2.75 }

#declare m1high = object{ HF_Sphere( Fn_moss_1, //Function,
                     0, // UseUVheight:  0 or 1
                     1, // UseUVtexture: 0 or 1
               <30,30>, // Resolution,
                     1, // Smooth,// 0 or 1
                    "", // FileName,
               <0,0,0>, // Center
                   2.5 ,// Radius
                  -1.4  // Depth
                     ) //-----------------------------------
} // end of HF_Sphere -------------------------------------- 

/*object{ HF_Sphere( Fn_moss_1, //Function,
                     0, // UseUVheight:  0 or 1
                     1, // UseUVtexture: 0 or 1
               <30,30>, // Resolution,
                     1, // Smooth,// 0 or 1
                    "", // FileName,
               <0,0,0>, // Center
                   2.5 ,// Radius
                  -1.4  // Depth
                     ) //-----------------------------------
} // end of HF_Sphere -------------------------------------- 
*/
/*
#declare  F_WrinklesA= function { pigment{wrinkles turbulence 0.095 omega 0.8 lambda 4 scale 0.255} }
#declare mCount=0;
union {
#while(mCount < 100)

#declare X = mr(1);
#declare Z = mr(1);

//#if (br(1) < f_distribution(X,0,Z))
#if(F_WrinklesA(X, 0.5, Z).red > 0.1)
Drop_Object(bigRoundRockNearBack, object { m1high scale <1, 0.5, 1>*(0.01+mr(0.01)) rotate <0, mr(360), 0> }, <0.25+(X*5), 6, 3+(Z*5)>, 1)
#end
#declare mCount=mCount+1;
#end         
material { mossMat } 
}
*/   


#macro getNatSpline(Surface, Pos, stepX, stepZ, stepXRand)
    //Allow the user to pass scalars as vectors
    #local lPos = Pos + <0,0,0>;
    #local hit=1;
    //Trace onto the surface  
    // estimate number of steps in spline 
    #local stepCount=0;
    #local hit=1;
    #while(hit = 1)
    #local N = <0,0,0>;
    #local SO = trace(Surface, lPos, <0, -1, 0.75>, N);

    //Check if we hit the surface
    #if (vlength(N)>0)   
        #local stepCount=stepCount+1;
    #else
        #local hit=0;           
    #end
        #local lPos=lPos+<0, 0, stepZ>;
    #end
    
    #if(stepCount < 2)
           spline { natural_spline 0.0, <0, 0, 0> 0.5, <0.005, 0.005, 0.005> 1.0, <.001, .001, .001> } 
    #else 
        // create the spline
        #local splineStep=1/(stepCount-1);
        #local splinePos=0; 
         
        #local hit=1;
        #local lPos = Pos + <0,0,0>;
    
        spline {
             natural_spline
             0.00, <0, 0, 0>   
        #while(hit = 1)
            #local N = <0,0,0>;
            #local SO = trace(Surface, lPos, <0, -1, 0.75>, N);
        
            //Check if we hit the surface
            #if (vlength(N)>0)   
                //record SplinePoint
                splinePos, SO
                #local splinePos=splinePos+splineStep;
            #else
                #local hit=0;
            #end
            #local lPos=lPos+<stepX+(-mr(stepXRand)+mr(stepXRand)), 0, stepZ>;
        #end
        } // end of spline
    #end
#end // End Macro



//Place_Object(largeBackRock1, object{ mkLimpet() rotate <90, 0, 0> }, <limpetPos, -1.65+lr(2), 0>, 1)
//Drop_Object(largeBackRock1, object { barn1 scale 0.125+br(0.175) rotate <0, br(360), 0> }, <-10+(X*12), 10, 9+(Z*8)>, 1)

#macro SeaweedPart(rad, spos, epos, tSpline, blobSpace, blobSize)
        #local lspos = spos;
        #local nextBlob=lspos;
        #local nextBlobSpace=blobSpace/2+sr(blobSpace);   
        #local srad=rad*2;
                
                

                #while (lspos < epos)      
                   
              
                   #local Direction = (tSpline(lspos+0.001) -tSpline(lspos-0.001));   


                   sphere { 0, (srad*0.9)+(sr(srad*0.1)), Strength scale <2, 0.1, 3>  
                //   transform {Reorient_Trans(x,Direction)}   
                   translate tSpline(lspos)  
                   }  
                   
                   #if(srad > rad)
                        #local srad=srad*0.994;
                   #else
                   
                   #if(vlength(tSpline(nextBlob)-tSpline(lspos)) > nextBlobSpace)
                        #local thisBlobSize=blobSize/2+sr(blobSize/2);   
                        sphere { 0, thisBlobSize*0.6, Strength scale <1, 1, 1.5> translate <0, 0, -thisBlobSize*0.4> transform {Reorient_Trans(z,Direction)} translate tSpline(lspos) }  
                        sphere { 0, thisBlobSize*0.8, Strength scale <1, 1, 1.4> translate <0, 0, -thisBlobSize*0.2> transform {Reorient_Trans(z,Direction)} translate tSpline(lspos) }  
                        sphere { 0, thisBlobSize*1.0, Strength scale <1, 1, 1.2> translate <0, 0, 0> transform {Reorient_Trans(z,Direction)} translate tSpline(lspos) }  
                        sphere { 0, thisBlobSize*0.8, Strength scale <1, 1, 1.3> translate <0, 0, thisBlobSize*0.2> transform {Reorient_Trans(z,Direction)} translate tSpline(lspos) }  
                        sphere { 0, thisBlobSize*0.6, Strength scale <1, 1, 1.2> translate <0, 0, thisBlobSize*0.4> transform {Reorient_Trans(z,Direction)} translate tSpline(lspos) }  
                        #local nextBlob=lspos;
                        #local nextBlobSpace=blobSpace/2+sr(blobSpace/2);

                   #end 

                   #end
//                   #local cRad=cRad*0.98;
                   #local lspos = getSplinePos(tSpline, lspos, srad/2, 0.001);  
                   #if(lspos >= epos)
                        #local lspos=epos;
                        #local thisBlobSize=blobSize/2+sr(blobSize/2);   
                        sphere { 0, thisBlobSize*0.6, Strength scale <1, 1, 1.5> translate <0, 0, -thisBlobSize*0.4> transform {Reorient_Trans(z,Direction)} translate tSpline(lspos) }  
                        sphere { 0, thisBlobSize*0.8, Strength scale <1, 1, 1.4> translate <0, 0, -thisBlobSize*0.2> transform {Reorient_Trans(z,Direction)} translate tSpline(lspos) }  
                        sphere { 0, thisBlobSize*1.0, Strength scale <1, 1, 1.2> translate <0, 0, 0> transform {Reorient_Trans(z,Direction)} translate tSpline(lspos) }  
                        sphere { 0, thisBlobSize*0.8, Strength scale <1, 1, 1.3> translate <0, 0, thisBlobSize*0.2> transform {Reorient_Trans(z,Direction)} translate tSpline(lspos) }  
                        sphere { 0, thisBlobSize*0.6, Strength scale <1, 1, 1.2> translate <0, 0, thisBlobSize*0.4> transform {Reorient_Trans(z,Direction)} translate tSpline(lspos) }  
                        #local nextBlob=lspos;
                        #local nextBlobSpace=blobSpace/2+sr(blobSpace/2);
                        #local lspos=epos;

                   #end 
                   

                #end                 
#end




#macro SeaweedStrand(swSpline)

    blob{
        threshold 0.6 // threshold (0.0 < threshold <= Strength) surface falloff threshold #
                        
        SeaweedPart(0.015+sr(0.005), 0.005, 1, swSpline, 0.45+sr(0.025), 0.035+sr(0.01))           

    }
#end


#declare lbMoss=largeBackRock1;

#declare xPos=1.5;
#declare darkVal=0;
#while(xPos < 4.5)  
#declare mStop=0.8-mr(0.4);  
#declare mCount=0;
#declare mScale=1;
//#declare mossSpline = getNatSpline(bigRoundRockNearBack, <1+xPos, 5, 2.5+mr(0.25)>, 0.05+mr(0.05), -0.25)
#declare mossSpline = getNatSpline(lbMoss, <-6+xPos, 7+mr(0.5), 7+mr(1)>, -0.1+mr(0.2), -0.25, 0.05+mr(0.05))

#if(darkVal > 1)
#declare darkVal=0;
object { SeaweedStrand(mossSpline) 
material { mossMatDark }  
translate <-0.1, 0, -(0.3+mr(0.05))>    
}          
#end 
union {
#declare mossSpline = getNatSpline(lbMoss, <-6+xPos, 7+mr(0.5), 7+mr(1)>, -0.1+mr(0.2), -0.25, 0.05+mr(0.05))
#while(mCount < mStop)
object { m1high scale <0.3+mr(0.3), 0.1+mr(0.05), 1>*(0.07+mr(0.07))*mScale rotate <mr(1), -20+mr(40), -20+mr(40)>    
translate mossSpline(mCount)
}
#declare mCount=mCount+0.001;  
#declare mScale=mScale*0.9996;
#end         
material { mossMat }  
//translate <0, mr(0.1), -mr(0.1)>
}
 
#declare darkVal=darkVal+mr(3);
#declare xPos=xPos+0.005+mr(0.01);
#end
#end
/********************* End of Green moss like Seaweed  ***************************/
   